@@ -61,7 +61,7 @@ ArchInputDialog::ArchInputDialog(FXWindow* win, FXString inp) :
         new FXLabel(contents, _("=> Warning: file name is not UTF-8 encoded!"), NULL,
                     LAYOUT_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_ROW);
     }
-    new FXButton(matrix3, _("\tSelect destination..."), minifiledialogicon, this, ID_BROWSE_PATH,
+    new FXButton(matrix3, _("\tSelect Destination..."), minifiledialogicon, this, ID_BROWSE_PATH,
                  FRAME_GROOVE | LAYOUT_RIGHT |
                  LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
 
@@ -136,7 +136,7 @@ long ArchInputDialog::onCmdKeyPress(FXObject* sender, FXSelector sel, void* ptr)
 long ArchInputDialog::onCmdBrowsePath(FXObject* sender, FXSelector sel, void* ptr)
 {
     // File dialog
-    FileDialog browse(this, _("Select a destination folder"));
+    FileDialog browse(this, _("Select a Destination Folder"));
 
     const char* patterns[] =
     {
