@@ -73,7 +73,7 @@ BrowseInputDialog::BrowseInputDialog(FXWindow* win, FXString inp, FXString messa
                             LAYOUT_CENTER_Y | LAYOUT_CENTER_X | TEXTFIELD_NORMAL | LAYOUT_FILL_COLUMN |
                             LAYOUT_FILL_ROW | LAYOUT_FILL_X);
     input->setText(inp);
-    new FXButton(matrix2, _("\tSelect destination..."), minifiledialogicon, this, ID_BROWSE_PATH, FRAME_GROOVE |
+    new FXButton(matrix2, _("\tSelect Destination..."), minifiledialogicon, this, ID_BROWSE_PATH, FRAME_GROOVE |
                  LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
     if (!xf_isutf8(message.text(), message.length()))
     {
@@ -130,15 +130,15 @@ long BrowseInputDialog::onCmdBrowsePath(FXObject* sender, FXSelector sel, void*
 
     if (browsetype == BROWSE_INPUT_FOLDER)
     {
-        title = _("Select a destination folder");
+        title = _("Select a Destination Folder");
     }
     else if (browsetype == BROWSE_INPUT_FILE)
     {
-        title = _("Select a file");
+        title = _("Select a File");
     }
     else
     {
-        title = _("Select a file or a destination folder");
+        title = _("Select a File or a Destination Folder");
     }
 
     // File dialog
