@@ -49,5 +49,16 @@ public:
     void selectAll();
     void CursorEnd();
     void setSelection(int, int);
+
+    FXuint getBrowseType()
+    {
+        return browsetype;
+    }
+    
+    void setBrowseType(FXuint type)
+    {
+        browsetype = type;
+    }
+
 };
 #endif
