@@ -65,7 +65,7 @@ FXIMPLEMENT(ColorWell, FXFrame, ColorWellMap, ARRAYNUMBER(ColorWellMap))
 
 
 
-// Init
+// Construct
 ColorWell::ColorWell()
 {
     flags |= FLAG_ENABLED | FLAG_DROPTARGET;
@@ -1086,7 +1086,7 @@ ColorSelector::ColorSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXui
     FXVerticalFrame* wellframe = new FXVerticalFrame(main, LAYOUT_FILL_Y, 0, 0, 0, 0, 0, 0, 10, 0, 0, 2);
 
     // Color sucker
-    new FXPicker(wellframe, _("\tPick color"), eyedropicon, this, ID_COLORPICK, JUSTIFY_CENTER_X | JUSTIFY_CENTER_Y |
+    new FXPicker(wellframe, _("\tPick Color"), eyedropicon, this, ID_COLORPICK, JUSTIFY_CENTER_X | JUSTIFY_CENTER_Y |
                  FRAME_GROOVE | LAYOUT_CENTER_X | LAYOUT_FIX_WIDTH | LAYOUT_FIX_HEIGHT, 0, 0, 56, 32, 0, 0, 0, 0);
 
     // Main color well
