@@ -6,11 +6,12 @@
 #include <fx.h>
 #include <fxkeys.h>
 
+#include "icons.h"
 #include "ComboBox.h"
 
 
 #define COMBOBOX_INS_MASK   (COMBOBOX_REPLACE | COMBOBOX_INSERT_BEFORE | COMBOBOX_INSERT_AFTER | \
-                              COMBOBOX_INSERT_FIRST | COMBOBOX_INSERT_LAST)
+                             COMBOBOX_INSERT_FIRST | COMBOBOX_INSERT_LAST)
 #define COMBOBOX_MASK       (COMBOBOX_STATIC | COMBOBOX_INS_MASK)
 
 
@@ -34,7 +35,14 @@ FXDEFMAP(ComboBox) ComboBoxMap[] =
     FXMAPFUNC(SEL_COMMAND, FXWindow::ID_GETINTVALUE, ComboBox::onFwdToText),
     FXMAPFUNC(SEL_COMMAND, FXWindow::ID_GETREALVALUE, ComboBox::onFwdToText),
     FXMAPFUNC(SEL_COMMAND, FXWindow::ID_GETSTRINGVALUE, ComboBox::onFwdToText),
-    FXMAPFUNC(SEL_KEYPRESS, 0, ComboBox::onKeyPress),
+    FXMAPFUNC(SEL_RIGHTBUTTONRELEASE, ComboBox::ID_TEXT, ComboBox::onCmdPopupMenu),
+    FXMAPFUNC(SEL_COMMAND, ComboBox::ID_COPY_TEXT, ComboBox::onCmdCopyText),
+    FXMAPFUNC(SEL_COMMAND, ComboBox::ID_CUT_TEXT, ComboBox::onCmdCutText),
+    FXMAPFUNC(SEL_COMMAND, ComboBox::ID_PASTE_TEXT, ComboBox::onCmdPasteText),
+    FXMAPFUNC(SEL_COMMAND, ComboBox::ID_PASTE_OPEN, ComboBox::onCmdPasteOpen),
+    FXMAPFUNC(SEL_COMMAND, ComboBox::ID_CLEAR_TEXT, ComboBox::onCmdClearText),
+    FXMAPFUNC(SEL_COMMAND, ComboBox::ID_CLEAR_LIST, ComboBox::onCmdClearList),
+    FXMAPFUNC(SEL_UPDATE, ComboBox::ID_PASTE_TEXT, ComboBox::onUpdYes),
 };
 
 
@@ -42,14 +50,16 @@ FXDEFMAP(ComboBox) ComboBoxMap[] =
 FXIMPLEMENT(ComboBox, FXPacker, ComboBoxMap, ARRAYNUMBER(ComboBoxMap))
 
 
-// Combo box
-ComboBox::ComboBox(FXComposite* p, int cols, FXObject* tgt, FXSelector sel, FXuint opts,
+// Construct
+ComboBox::ComboBox(FXComposite* p, int cols, FXbool addr, FXbool clrbtn, FXObject* tgt, FXSelector sel, FXuint opts,
                    int x, int y, int w, int h, int pl, int pr, int pt, int pb) :
     FXPacker(p, opts, x, y, w, h, 0, 0, 0, 0, 0, 0)
 {
     flags |= FLAG_ENABLED;
     target = tgt;
     message = sel;
+    address = addr;
+    clearbutton = clrbtn;
 
     // !!! Hack to set options to TEXTFIELD_NORMAL instead of 0 (used by the Clearlooks theme)
     field = new FXTextField(this, cols, this, ComboBox::ID_TEXT, TEXTFIELD_NORMAL, 0, 0, 0, 0, pl, pr, pt, pb);
@@ -62,6 +72,15 @@ ComboBox::ComboBox(FXComposite* p, int cols, FXObject* tgt, FXSelector sel, FXui
     pane = new FXPopup(this, FRAME_LINE);
     list = new FXList(pane, this, ComboBox::ID_LIST, LIST_BROWSESELECT | LIST_AUTOSELECT | LAYOUT_FILL_X |
                       LAYOUT_FILL_Y | SCROLLERS_TRACK | HSCROLLER_NEVER);
+
+    // If clear list button
+    if (clearbutton)
+    {
+        FXHorizontalFrame* frame = new FXHorizontalFrame(pane, JUSTIFY_LEFT | LAYOUT_SIDE_BOTTOM | LAYOUT_FILL_X,
+                                                         0, 0, 0, 0, 2, 2, 2, 2);
+        new FXButton(frame, _("Clear\tReset history list"), minideleteicon, this, ID_CLEAR_LIST);
+    }
+    
     if (options & COMBOBOX_STATIC)
     {
         list->setScrollStyle(SCROLLERS_TRACK | HSCROLLING_OFF);
@@ -75,28 +94,6 @@ ComboBox::ComboBox(FXComposite* p, int cols, FXObject* tgt, FXSelector sel, FXui
 }
 
 
-// Pass key events to list if static combo box otherwise to text field
-long ComboBox::onKeyPress(FXObject* sender, FXSelector sel, void* ptr)
-{
-    if (options & COMBOBOX_STATIC)
-    {
-        if (list->onKeyPress(sender, sel, ptr))
-        {
-            return 1;
-        }
-    }
-    else
-    {
-        if (field->onKeyPress(sender, sel, ptr))
-        {
-            return 1;
-        }
-    }
-
-    return 0;
-}
-
-
 // Create window
 void ComboBox::create()
 {
@@ -894,3 +891,96 @@ ComboBox::~ComboBox()
     button = (FXMenuButton*)-1L;
     list = (FXList*)-1L;
 }
+
+
+// Popup menu on text field
+long ComboBox::onCmdPopupMenu(FXObject*, FXSelector, void*)
+{
+    int x, y;
+    FXuint state;
+
+    list->getCursorPosition(x, y, state);
+
+    // Right mouse popup
+    popupmenu = new FXMenuPane(this);
+    new FXMenuCommand(popupmenu, _("&Copy"), minicopyicon, this, ID_COPY_TEXT);
+    new FXMenuCommand(popupmenu, _("C&ut"), minicuticon, this, ID_CUT_TEXT);
+    new FXMenuCommand(popupmenu, _("&Paste"), minipasteicon, this, ID_PASTE_TEXT);
+    
+    // For address bar, add a menu to paste and open directory
+    if (address)
+    {
+        new FXMenuCommand(popupmenu, _("Paste and &Open"), minigotodiricon, this, ID_PASTE_OPEN);        
+    }
+    new FXMenuCommand(popupmenu, _("C&lear"), minicloseicon, this, ID_CLEAR_TEXT);
+
+    getRoot()->getCursorPosition(x, y, state);
+
+    popupmenu->create();
+    popupmenu->popup(NULL, x, y);
+
+    return 1;
+}
+
+
+// Copy text
+long ComboBox::onCmdCopyText(FXObject*, FXSelector, void*)
+{
+    field->selectAll();
+    field->handle(this, FXSEL(SEL_COMMAND, FXTextField::ID_COPY_SEL), NULL);
+
+    return 1;
+}
+
+
+// Cut text
+long ComboBox::onCmdCutText(FXObject*, FXSelector, void*)
+{
+    field->selectAll();
+    field->handle(this, FXSEL(SEL_COMMAND, FXTextField::ID_CUT_SEL), NULL);
+
+    return 1;
+}
+
+
+// Paste text
+long ComboBox::onCmdPasteText(FXObject*, FXSelector, void*)
+{
+    field->selectAll();
+    field->handle(this, FXSEL(SEL_COMMAND, FXTextField::ID_PASTE_SEL), NULL);
+
+    return 1;
+}
+
+
+// Paste and open directory
+long ComboBox::onCmdPasteOpen(FXObject*, FXSelector, void*)
+{
+    field->selectAll();
+    field->handle(this, FXSEL(SEL_COMMAND, FXTextField::ID_PASTE_SEL), NULL);
+    
+    // Send return key to FXTextField object
+    FXEvent event;
+    event.code = KEY_Return;   
+    field->handle(this, FXSEL(SEL_KEYPRESS, 0), &event);
+
+    return 1;
+}
+
+
+// Clear text
+long ComboBox::onCmdClearText(FXObject*, FXSelector, void*)
+{
+    field->selectAll();
+    field->handle(this, FXSEL(SEL_COMMAND, FXTextField::ID_DELETE_ALL), NULL);
+
+    return 1;
+}
+
+
+// Clear list
+long ComboBox::onCmdClearList(FXObject*, FXSelector, void*)
+{
+    clearItems();
+    return 1;
+}
