@@ -105,7 +105,7 @@ FXDEFMAP(DirList) DirListMap[] =
 FXIMPLEMENT(DirList, FXTreeList, DirListMap, ARRAYNUMBER(DirListMap))
 
 
-// Directory List Widget
+// Construct
 DirList::DirList(FXWindow* focuswin, FXComposite* p, FXObject* tgt, FXSelector sel,
                  FXuint opts, int x, int y, int w, int h) :
     FXTreeList(p, tgt, sel, opts, x, y, w, h), pattern("*")
@@ -685,9 +685,9 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
         FXMenuPane menu(this);
         int x, y;
         getRoot()->getCursorPosition(x, y, state);
-        new FXMenuCommand(&menu, _("Copy here"), minicopyicon, this, DirList::ID_DRAG_COPY);
-        new FXMenuCommand(&menu, _("Move here"), minimoveicon, this, DirList::ID_DRAG_MOVE);
-        new FXMenuCommand(&menu, _("Link here"), minilinktoicon, this, DirList::ID_DRAG_LINK);
+        new FXMenuCommand(&menu, _("Copy Here"), minicopyicon, this, DirList::ID_DRAG_COPY);
+        new FXMenuCommand(&menu, _("Move Here"), minimoveicon, this, DirList::ID_DRAG_MOVE);
+        new FXMenuCommand(&menu, _("Link Here"), minilinktoicon, this, DirList::ID_DRAG_LINK);
         new FXMenuSeparator(&menu);
         new FXMenuCommand(&menu, _("Cancel"), NULL, this, DirList::ID_DRAG_REJECT);
         menu.create();
@@ -729,17 +729,17 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
         // File object
         if (dropaction == DRAG_COPY)
         {
-            f = new File(this, _("Copy files"), COPY, num);
+            f = new File(this, _("Copy Files"), COPY, num);
             f->create();
         }
         else if (dropaction == DRAG_MOVE)
         {
-            f = new File(this, _("Move files"), MOVE, num);
+            f = new File(this, _("Move Files"), MOVE, num);
             f->create();
         }
         else if (dropaction == DRAG_LINK)
         {
-            f = new File(this, _("Symlink files"), SYMLINK, num);
+            f = new File(this, _("Symlink Files"), SYMLINK, num);
             f->create();
         }
         else
@@ -796,6 +796,8 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
             // File operation dialog, if needed
             if (((!confirm_dnd) | ctrlshiftkey) & ask_before_copy & showdialog)
             {
+                f->hideProgressDialog();
+
                 FXIcon* icon = NULL;
                 FXString title, message;
                 if (dropaction == DRAG_COPY)
@@ -808,7 +810,7 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
                     }
                     else
                     {
-                        title.format(_("Copy %s files/folders.\nFrom: %s"), FXStringVal(num).text(), sourcedir.text());
+                        message.format(_("Copy %s files/folders from: %s"), FXStringVal(num).text(), sourcedir.text());
                     }
                 }
                 else if (dropaction == DRAG_MOVE)
@@ -821,7 +823,7 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
                     }
                     else
                     {
-                        title.format(_("Move %s files/folders.\nFrom: %s"), FXStringVal(num).text(), sourcedir.text());
+                        message.format(_("Move %s files/folders from: %s"), FXStringVal(num).text(), sourcedir.text());
                     }
                 }
                 else if ((dropaction == DRAG_LINK) && (num == 1))
@@ -848,6 +850,9 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
                 }
             }
 
+            f->showProgressDialog();
+            getApp()->beginWaitCursor();
+
             // Move the source file
             if (dropaction == DRAG_MOVE)
             {
@@ -960,6 +965,8 @@ long DirList::onDNDDrop(FXObject* sender, FXSelector sel, void* ptr)
                 q += 2;
             }
             p = q;
+
+            getApp()->endWaitCursor();
         }
 out:
         delete f;
@@ -2010,7 +2017,7 @@ fnd:
             // Mounted devices may have a specific icon
             if (mtdevices->find(pathname.text()))
             {
-                type = _("Mount point");
+                type = _("Mount Point");
 
                 if (xf_strequal(mtdevices->find(pathname.text()), "cifs"))
                 {
@@ -2027,7 +2034,7 @@ fnd:
             // Devices found in fstab may have a specific icon
             if (fsdevices->find(pathname.text()))
             {
-                type = _("Mount point");
+                type = _("Mount Point");
 
                 if (xf_strequal(fsdevices->find(pathname.text()), "harddrive"))
                 {
@@ -2653,7 +2660,7 @@ long DirList::onQueryTip(FXObject* sender, FXSelector sel, void* ptr)
                 // Root folder
                 if (item->getText() == ROOTDIR)
                 {
-                    string = _("Root folder");
+                    string = _("Root Folder");
                 }
                 // Other folders
                 else
