@@ -8,7 +8,6 @@
 #include "BookmarkDialog.h"
 #include "BrowseInputDialog.h"
 
-
 #include <sys/types.h>
 
 
@@ -27,11 +26,11 @@ protected:
     FXString trashfileslocation;
     FXString trashinfolocation;
     FXString startlocation;
-    FXDragType urilistType = 0;                                 // Standard uri-list type
-    FXDragType xfelistType = 0;                                 // Xfe, Gnome and XFCE list type
-    FXDragType kdelistType = 0;                                 // KDE list type
-    FXDragType utf8Type = 0;                                    // UTF-8 text type
-    FXbool clipboard_locked = false;                            // Clipboard locked to prevent changes when viewing it
+    FXDragType urilistType = 0;                    // Standard uri-list type
+    FXDragType xfelistType = 0;                    // Xfe, Gnome and XFCE list type
+    FXDragType kdelistType = 0;                    // KDE list type
+    FXDragType utf8Type = 0;                       // UTF-8 text type
+    FXbool clipboard_locked = false;               // Clipboard locked to prevent changes when viewing it
     InputDialog* newdirdialog = NULL;
     ArchInputDialog* archdialog = NULL;
     BrowseInputDialog* operationdialog = NULL;
@@ -40,15 +39,16 @@ protected:
     BookmarkDialog* modifybookmarkdialog = NULL;
     FXbool fromPaste = false;
     FXWindow* focuswindow = NULL;
-    TextLabel* paneltitle = NULL;                               // Panel title
-    FXTabBook* tabbook = NULL;                                  // Tab book
-    FXbool isactive = false;                                    // Flag to indicate is panel has keyboard focus
-    FXbool stopListRefresh = false;                             // To stop refreshing in some cases
-    time_t curr_mtime = 0;                                      // Current directory mtime
-    FXString curr_dirpath;                                      // Current directory path
-    FXbool allowDirsizeRefresh = true;                          // Allow or avoid directory size refresh
+    TextLabel* paneltitle = NULL;                  // Panel title
+    FXTabBook* tabbook = NULL;                     // Tab book
+    FXbool isactive = false;                       // Flag to indicate is panel has keyboard focus
+    FXbool stopListRefresh = false;                // To stop refreshing in some cases
+    time_t curr_mtime = 0;                         // Current directory mtime
+    FXString curr_dirpath;                         // Current directory path
+    FXbool allowDirsizeRefresh = true;             // Allow or avoid directory size refresh
+    FXuint dirpanel_mode = 0;                      // Panel type: 0 => places and tree, 1 => places only, 2 => tree only
 
-    FXSplitter* splitter = NULL;                                // Splitter for mounts and bookmarks list
+    FXSplitter* splitter = NULL;                   // Splitter for mounts and bookmarks list
 
     FXuint single_click = SINGLE_CLICK_NONE;
 
@@ -66,7 +66,7 @@ public:
     ~DirPanel();
     enum
     {
-        IDFILELIST=FXVerticalFrame::ID_LAST,
+        ID_FILELIST=FXVerticalFrame::ID_LAST,
         ID_STOP_LIST_REFRESH_TIMER,
         ID_BOOKMARKS,
         ID_PLACES,
@@ -99,13 +99,16 @@ public:
         ID_DIRSIZE_REFRESH,
         ID_POPUP_MENU_DIRLIST,
         ID_POPUP_MENU_PLACES,
-        ID_OPEN_PLACE,
+        ID_OPEN_PLACE_NEW_TAB,
+        ID_OPEN_PLACE_NEW_WINDOW,
         ID_PLACE_PROPERTIES,
         ID_POPUP_MENU_MOUNTS,
-        ID_OPEN_MOUNT,
+        ID_OPEN_MOUNT_NEW_TAB,
+        ID_OPEN_MOUNT_NEW_WINDOW,
         ID_MOUNT_PROPERTIES,
         ID_POPUP_MENU_BOOKMARKS,
-        ID_OPEN_BOOKMARK,
+        ID_OPEN_BOOKMARK_NEW_TAB,
+        ID_OPEN_BOOKMARK_NEW_WINDOW,
         ID_MODIFY_BOOKMARK,
         ID_REMOVE_BOOKMARK,
         ID_BOOKMARK_PROPERTIES,
@@ -135,19 +138,22 @@ public:
 
     long onCmdPopupMenuPlaces(FXObject*, FXSelector, void*);
     long onCmdGotoPlace(FXObject*, FXSelector, void*);
-    long onCmdOpenPlace(FXObject*, FXSelector, void*);
+    long onCmdOpenPlaceNewTab(FXObject*, FXSelector, void*);
+    long onCmdOpenPlaceNewWindow(FXObject*, FXSelector, void*);
     long onCmdPlaceProperties(FXObject*, FXSelector, void*);
     long onUpdPlaces(FXObject*, FXSelector, void*);
 
     long onCmdPopupMenuMounts(FXObject*, FXSelector, void*);
     long onCmdGotoMount(FXObject*, FXSelector, void*);
-    long onCmdOpenMount(FXObject*, FXSelector, void*);
+    long onCmdOpenMountNewTab(FXObject*, FXSelector, void*);
+    long onCmdOpenMountNewWindow(FXObject*, FXSelector, void*);
     long onCmdMountProperties(FXObject*, FXSelector, void*);
     long onUpdMounts(FXObject*, FXSelector, void*);
 
     long onCmdPopupMenuBookmarks(FXObject*, FXSelector, void*);
     long onCmdAddBookmark(FXObject*, FXSelector, void*);
-    long onCmdOpenBookmark(FXObject*, FXSelector, void*);
+    long onCmdOpenBookmarkNewTab(FXObject*, FXSelector, void*);
+    long onCmdOpenBookmarkNewWindow(FXObject*, FXSelector, void*);
     long onCmdBookmarkProperties(FXObject*, FXSelector, void*);
     long onCmdModifyBookmark(FXObject*, FXSelector, void*);
     long onCmdRemoveBookmark(FXObject*, FXSelector, void*);
