@@ -32,10 +32,10 @@ FXDEFMAP(FileSelector) FileSelectorMap[] =
 {
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_ACCEPT, FileSelector::onCmdAccept),
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_FILEFILTER, FileSelector::onCmdFilter),
-    FXMAPFUNC(SEL_DOUBLECLICKED, FileSelector::IDFILELIST, FileSelector::onCmdItemDoubleClicked),
-    FXMAPFUNC(SEL_CLICKED, FileSelector::IDFILELIST, FileSelector::onCmdItemClicked),
-    FXMAPFUNC(SEL_SELECTED, FileSelector::IDFILELIST, FileSelector::onCmdItemSelected),
-    FXMAPFUNC(SEL_DESELECTED, FileSelector::IDFILELIST, FileSelector::onCmdItemDeselected),
+    FXMAPFUNC(SEL_DOUBLECLICKED, FileSelector::ID_FILELIST, FileSelector::onCmdItemDoubleClicked),
+    FXMAPFUNC(SEL_CLICKED, FileSelector::ID_FILELIST, FileSelector::onCmdItemClicked),
+    FXMAPFUNC(SEL_SELECTED, FileSelector::ID_FILELIST, FileSelector::onCmdItemSelected),
+    FXMAPFUNC(SEL_DESELECTED, FileSelector::ID_FILELIST, FileSelector::onCmdItemDeselected),
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_DIR_UP, FileSelector::onCmdDirUp),
     FXMAPFUNC(SEL_UPDATE, FileSelector::ID_DIR_UP, FileSelector::onUpdDirUp),
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_DIR_BACK, FileSelector::onCmdDirBack),
@@ -50,7 +50,7 @@ FXDEFMAP(FileSelector) FileSelectorMap[] =
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_NEWDIR, FileSelector::onCmdNewDir),
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_NEWFILE, FileSelector::onCmdNewFile),
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_WORK, FileSelector::onCmdWork),
-    FXMAPFUNC(SEL_RIGHTBUTTONRELEASE, FileSelector::IDFILELIST, FileSelector::onCmdPopupMenu),
+    FXMAPFUNC(SEL_RIGHTBUTTONRELEASE, FileSelector::ID_FILELIST, FileSelector::onCmdPopupMenu),
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_POPUP_MENU, FileSelector::onCmdPopupMenu),
     FXMAPFUNC(SEL_COMMAND, FileSelector::ID_FILTER, FileSelector::onCmdItemFilter),
     FXMAPFUNC(SEL_UPDATE, FileSelector::ID_FILTER, FileSelector::onUpdItemFilter),
@@ -66,7 +66,7 @@ FXIMPLEMENT(FileSelector, FXPacker, FileSelectorMap, ARRAYNUMBER(FileSelectorMap
 // Default pattern
 static const char allfiles[] = "All Files (*)";
 
-// File selector object
+// Construct
 FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint opts, int x, int y, int w, int h) :
     FXPacker(p, opts, x, y, w, h, 0, 0, 0, 0, 0, 0)
 {
@@ -167,7 +167,7 @@ FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
     }
     nbCols = i;
 
-    list = new FileList(this, cont, idCol, nbCols, this, IDFILELIST, showthumbnails, 0, 0, options);
+    list = new FileList(this, cont, idCol, nbCols, this, ID_FILELIST, showthumbnails, 0, 0, options);
 
     // Set list colors and columns size for detailed mode
     list->setTextColor(getApp()->reg().readColorEntry("SETTINGS", "listforecolor", FXRGB(0, 0, 0)));
@@ -242,7 +242,7 @@ FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
     new FXLabel(fields, _("File F&ilter:"), NULL, JUSTIFY_LEFT | LAYOUT_CENTER_Y);
     FXHorizontalFrame* filterframe = new FXHorizontalFrame(fields, LAYOUT_FILL_COLUMN |
                                                            LAYOUT_FILL_X | LAYOUT_FILL_Y);
-    filefilter = new ComboBox(filterframe, 10, this, ID_FILEFILTER, COMBOBOX_STATIC | LAYOUT_FILL_X);
+    filefilter = new ComboBox(filterframe, 10, false, false, this, ID_FILEFILTER, COMBOBOX_STATIC | LAYOUT_FILL_X);
     filefilter->setNumVisible(4);
 
     readonly = new FXCheckButton(filterframe, _("Read Only") + FXString(" "), NULL, 0, ICON_BEFORE_TEXT |
@@ -259,7 +259,7 @@ FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
     new FXFrame(buttons, LAYOUT_FIX_WIDTH, 0, 0, 4, 1);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "go_back", "Ctrl-Backspace");
-    btn = new FXButton(buttons, TAB + _("Go to previous folder") + PARS(key), minidirbackicon, this, ID_DIR_BACK,
+    btn = new FXButton(buttons, TAB + _("Go to Previous Folder") + PARS(key), minidirbackicon, this, ID_DIR_BACK,
                        BUTTON_TOOLBAR | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
@@ -268,7 +268,7 @@ FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
                                     LAYOUT_FILL_Y | FRAME_GROOVE | ARROW_DOWN | ARROW_TOOLBAR);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "go_forward", "Shift-Backspace");
-    btn = new FXButton(buttons, TAB + _("Go to next folder") + PARS(key), minidirforwardicon, this, ID_DIR_FORWARD,
+    btn = new FXButton(buttons, TAB + _("Go to Next Folder") + PARS(key), minidirforwardicon, this, ID_DIR_FORWARD,
                        BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
@@ -276,45 +276,45 @@ FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
     btnforwardhist = new FXArrowButton(buttons, this, ID_DIR_FORWARD_HIST,
                                        LAYOUT_FILL_Y | FRAME_GROOVE | ARROW_DOWN | ARROW_TOOLBAR);
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "go_up", "Backspace");
-    btn = new FXButton(buttons, TAB + _("Go to parent folder") + PARS(key), minidirupicon, this, ID_DIR_UP,
+    btn = new FXButton(buttons, TAB + _("Go to Parent Folder") + PARS(key), minidirupicon, this, ID_DIR_UP,
                        BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "go_home", "Ctrl-H");
-    btn = new FXButton(buttons, TAB + _("Go to home folder") + PARS(key), minihomeicon, this, ID_HOME,
+    btn = new FXButton(buttons, TAB + _("Go to Home Folder") + PARS(key), minihomeicon, this, ID_HOME,
                        BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "go_work", "Shift-F2");
-    btn = new FXButton(buttons, TAB + _("Go to working folder") + PARS(key), miniworkicon, this, ID_WORK,
+    btn = new FXButton(buttons, TAB + _("Go to Working Folder") + PARS(key), miniworkicon, this, ID_WORK,
                        BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "new_folder", "F7");
-    btn = new FXButton(buttons, TAB + _("New folder") + PARS(key), minifoldernewicon, this, ID_NEWDIR,
+    btn = new FXButton(buttons, TAB + _("New Folder") + PARS(key), minifoldernewicon, this, ID_NEWDIR,
                        BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "big_icons", "F10");
-    btn = new FXButton(buttons, TAB + _("Big icon list") + PARS(key), minibigiconsicon, list,
+    btn = new FXButton(buttons, TAB + _("Big Icon List") + PARS(key), minibigiconsicon, list,
                        FileList::ID_SHOW_BIG_ICONS, BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3,
                        3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "small_icons", "F11");
-    btn = new FXButton(buttons, TAB + _("Small icon list") + PARS(key), minismalliconsicon, list,
+    btn = new FXButton(buttons, TAB + _("Small Icon List") + PARS(key), minismalliconsicon, list,
                        FileList::ID_SHOW_MINI_ICONS, BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3,
                        3, 3);
     hotkey = xf_parseaccel(key);
     btn->addHotKey(hotkey);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "detailed_file_list", "F12");
-    btn = new FXButton(buttons, TAB + _("Detailed file list") + PARS(key), minidetailsicon, list,
+    btn = new FXButton(buttons, TAB + _("Detailed File List") + PARS(key), minidetailsicon, list,
                        FileList::ID_SHOW_DETAILS, BUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3,
                        3);
     hotkey = xf_parseaccel(key);
@@ -322,14 +322,14 @@ FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "hidden_files", "Ctrl-F6");
     tglbtn = new FXToggleButton(buttons, TAB + _("Show hidden files") + PARS(key),
-                                TAB + _("Hide hidden files") + PARS(key),
+                                TAB + _("Hide Hidden Files") + PARS(key),
                                 minishowhiddenicon, minihidehiddenicon, list, FileList::ID_TOGGLE_HIDDEN,
                                 TOGGLEBUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
     tglbtn->addHotKey(hotkey);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "thumbnails", "Ctrl-F7");
-    tglbtn = new FXToggleButton(buttons, TAB + _("Show thumbnails") + PARS(key), TAB + _("Hide thumbnails") + PARS(key),
+    tglbtn = new FXToggleButton(buttons, TAB + _("Show Thumbnails") + PARS(key), TAB + _("Hide thumbnails") + PARS(key),
                                 minishowthumbicon, minihidethumbicon, list, FileList::ID_TOGGLE_THUMBNAILS,
                                 TOGGLEBUTTON_TOOLBAR | LAYOUT_CENTER_Y | FRAME_GROOVE, 0, 0, 0, 0, 3, 3, 3, 3);
     hotkey = xf_parseaccel(key);
@@ -341,7 +341,7 @@ FileSelector::FileSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
                        BUTTON_TOOLBAR | LAYOUT_LEFT | LAYOUT_CENTER_Y | ICON_BEFORE_TEXT | FRAME_NONE);
 
     filterlabel = new FXLabel(buttons, "", NULL, JUSTIFY_LEFT | LAYOUT_LEFT);
-    closefilter = new FXButton(buttons, TAB + _("Close filter"), miniclosefiltericon, this->list,
+    closefilter = new FXButton(buttons, TAB + _("Close Filter"), miniclosefiltericon, this->list,
                                FileList::ID_CLOSE_FILTER,
                                BUTTON_TOOLBAR | LAYOUT_LEFT | LAYOUT_CENTER_Y | ICON_BEFORE_TEXT | FRAME_NONE);
 
@@ -1316,11 +1316,10 @@ long FileSelector::onCmdItemFilter(FXObject* sender, FXSelector sel, void*)
     int i;
     FXString pat = list->getPattern();
 
-
     if (filterdialog == NULL)
     {
-        filterdialog = new HistInputDialog(this, pat, _("Show:"), _("Filter"), "", bigfiltericon, HIST_INPUT_FILE, true,
-                                           _("Also apply to folders"));
+        filterdialog = new HistInputDialog(this, pat, _("Show:"), _("Filter"), "", bigfiltericon, false, true,
+                                           HIST_INPUT_FILE, true, _("Also apply to folders"));
     }
 
     filterdialog->clearItems();
@@ -1363,6 +1362,12 @@ long FileSelector::onCmdItemFilter(FXObject* sender, FXSelector sel, void*)
     list->onCmdRefresh(0, 0, 0);
     list->setFocus();
 
+    // If list has been cleared, set history size to zero
+    if (filterdialog->getHistorySize() == 0)
+    {
+        FilterNum = 0;
+    }
+
     return 1;
 }
 
@@ -1509,7 +1514,7 @@ FXString* FileSelector::getFilenames() const
             if (n > 0)
             {
                 // Limit the number of files to open
-                n = FXMAX(n, NMAX_OPEN_FILES);
+                n = FXMAX(n, MAX_OPEN_FILES);
 
                 files = new FXString [n + 1];
                 for (i = n = 0; i < list->getNumItems(); i++)
@@ -1534,7 +1539,7 @@ FXString* FileSelector::getFilenames() const
             if (n > 0)
             {
                 // Limit the number of files to open
-                n = FXMAX(n, NMAX_OPEN_FILES);
+                n = FXMAX(n, MAX_OPEN_FILES);
 
                 files = new FXString [n + 1];
                 for (i = n = 0; i < list->getNumItems(); i++)
@@ -1804,49 +1809,49 @@ FileSelector::~FileSelector()
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "size_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_SIZE)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_SIZE)));
     }
     isShown = getApp()->reg().readUnsignedEntry("SETTINGS", "view_col_type", 1);
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "type_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_TYPE)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_TYPE)));
     }
     isShown = getApp()->reg().readUnsignedEntry("SETTINGS", "view_col_ext", 1);
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "ext_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_EXT)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_EXT)));
     }
     isShown = getApp()->reg().readUnsignedEntry("SETTINGS", "view_col_date", 1);
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "date_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_DATE)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_DATE)));
     }
     isShown = getApp()->reg().readUnsignedEntry("SETTINGS", "view_col_user", 1);
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "user_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_USER)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_USER)));
     }
     isShown = getApp()->reg().readUnsignedEntry("SETTINGS", "view_col_group", 1);
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "group_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_GROUP)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_GROUP)));
     }
     isShown = getApp()->reg().readUnsignedEntry("SETTINGS", "view_col_perms", 1);
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "perms_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_PERMS)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_PERMS)));
     }
     isShown = getApp()->reg().readUnsignedEntry("SETTINGS", "view_col_link", 1);
     if (isShown)
     {
         getApp()->reg().writeUnsignedEntry("FILEDIALOG", "link_size",
-                                           list->getHeaderSize(list->getHeaderIndex(FileList::ID_COL_LINK)));
+                                           (FXuint)list->getHeaderSize((FXuint)list->getHeaderIndex(FileList::ID_COL_LINK)));
     }
 
     getApp()->reg().writeUnsignedEntry("FILEDIALOG", "liststyle", getFileBoxStyle());
@@ -1890,17 +1895,17 @@ long FileSelector::onCmdPopupMenu(FXObject* sender, FXSelector sel, void* ptr)
 
     getRoot()->getCursorPosition(x, y, state);
 
-    new FXMenuCommand(&menu, _("Go ho&me"), minihomeicon, this, ID_HOME);
-    new FXMenuCommand(&menu, _("Go &work"), miniworkicon, this, ID_WORK);
-    new FXMenuCommand(&menu, _("New &file..."), mininewfileicon, this, ID_NEWFILE);
-    new FXMenuCommand(&menu, _("New f&older..."), minifoldernewicon, this, ID_NEWDIR);
+    new FXMenuCommand(&menu, _("Go Ho&me"), minihomeicon, this, ID_HOME);
+    new FXMenuCommand(&menu, _("Go &Work"), miniworkicon, this, ID_WORK);
+    new FXMenuCommand(&menu, _("New &File..."), mininewfileicon, this, ID_NEWFILE);
+    new FXMenuCommand(&menu, _("New F&older..."), minifoldernewicon, this, ID_NEWDIR);
     new FXMenuSeparator(&menu);
-    new FXMenuCheck(&menu, _("&Hidden files"), list, FileList::ID_TOGGLE_HIDDEN);
+    new FXMenuCheck(&menu, _("&Hidden Files"), list, FileList::ID_TOGGLE_HIDDEN);
     new FXMenuCheck(&menu, _("Thum&bnails"), list, FileList::ID_TOGGLE_THUMBNAILS);
     new FXMenuSeparator(&menu);
-    new FXMenuRadio(&menu, _("B&ig icons"), list, IconList::ID_SHOW_BIG_ICONS);
-    new FXMenuRadio(&menu, _("&Small icons"), list, IconList::ID_SHOW_MINI_ICONS);
-    new FXMenuRadio(&menu, _("Fu&ll file list"), list, IconList::ID_SHOW_DETAILS);
+    new FXMenuRadio(&menu, _("B&ig Icons"), list, IconList::ID_SHOW_BIG_ICONS);
+    new FXMenuRadio(&menu, _("&Small Icons"), list, IconList::ID_SHOW_MINI_ICONS);
+    new FXMenuRadio(&menu, _("&Detailed File List"), list, IconList::ID_SHOW_DETAILS);
     new FXMenuSeparator(&menu);
     new FXMenuCheck(&menu, _("Autos&ize"), list, FileList::ID_AUTOSIZE);
     new FXMenuRadio(&menu, _("&Rows"), list, FileList::ID_ARRANGE_BY_ROWS);
@@ -1916,9 +1921,9 @@ long FileSelector::onCmdPopupMenu(FXObject* sender, FXSelector sel, void* ptr)
     new FXMenuRadio(&menu, _("&Permissions"), list, FileList::ID_COL_PERMS);
     new FXMenuRadio(&menu, _("&Link"), list, FileList::ID_COL_LINK);
     new FXMenuSeparator(&menu);
-    new FXMenuCheck(&menu, _("Ignore c&ase"), list, FileList::ID_SORT_CASE);
-    new FXMenuCheck(&menu, _("Fold&ers first"), list, FileList::ID_DIRS_FIRST);
-    new FXMenuCheck(&menu, _("Re&verse order"), list, FileList::ID_SORT_REVERSE);
+    new FXMenuCheck(&menu, _("Ignore C&ase"), list, FileList::ID_SORT_CASE);
+    new FXMenuCheck(&menu, _("Fold&ers First"), list, FileList::ID_DIRS_FIRST);
+    new FXMenuCheck(&menu, _("Re&verse Order"), list, FileList::ID_SORT_REVERSE);
 
     menu.create();
     menu.popup(NULL, x, y);
