@@ -90,7 +90,7 @@ public:
     {
         ID_FILEFILTER=FXPacker::ID_LAST,
         ID_ACCEPT,
-        IDFILELIST,
+        ID_FILELIST,
         ID_POPUP_MENU,
         ID_DIR_UP,
         ID_DIR_BACK,
