@@ -317,8 +317,8 @@ public:
     static int descendingOrigpathCaseMix(const IconItem*, const IconItem*);
 
     int getHeaderIndex(FXuint);
-    int getHeaderSize(int);
-    void setHeaderSize(int, int);
+    int getHeaderSize(FXuint);
+    void setHeaderSize(FXuint, FXuint);
 
     FXString labels[NMAX_COLS + 3];
 
