@@ -46,6 +46,7 @@ protected:
     FXDragType kdelistType = 0;                           // KDE list type
     FXDragType utf8Type = 0;                              // UTF-8 text type
     FXbool clipboard_locked = false;                      // Clipboard locked to prevent changes when viewing it
+    progsmap progs;                                       // Map between program string identifiers and integer indexes
     InputDialog* newfiledialog = NULL;
     InputDialog* newdirdialog = NULL;
     InputDialog* newlinkdialog = NULL;
@@ -58,19 +59,16 @@ protected:
     BrowseInputDialog* comparedialog = NULL;
     BookmarkDialog* addbookmarkdialog = NULL;
     TextLabel* pathtext = NULL;
-
     FXuint single_click = SINGLE_CLICK_NONE;
-
     FXuint nbCols = 0;
-
     FXbool fromPaste = false;
     FXbool ctrl = false;                                  // Flag to select the right click control menu
     FXbool shiftf10 = false;                              // Flag indicating that Shift-F10 was pressed
     FXbool isactive = false;
     FXbool stopListRefresh = false;
     FXColor attenclr = FXRGB(0, 0, 0);
-    progsmap progs;                                       // Map between program string identifiers and integer indexes
-
+    FXbool sameFileType = false;                           // Flag indicating that two selected items have
+                                                           // the same file type (files or directories)
 public:
 
     FilePanel(FXWindow* owner, const char*, FXComposite*, DirPanel*, FXuint*, FXuint, FXuint name_size = 200,
@@ -102,7 +100,7 @@ public:
 
     enum
     {
-        IDFILELIST=FXVerticalFrame::ID_LAST,
+        ID_FILELIST=FXVerticalFrame::ID_LAST,
         ID_STOP_LIST_REFRESH_TIMER,
         ID_DIRECTORY_UP,
         ID_VIEW,
@@ -313,7 +311,7 @@ public:
     }
 
     // Get header size given its index
-    int getHeaderSize(int index) const
+    int getHeaderSize(FXuint index) const
     {
         return list->getHeaderSize(index);
     }
