@@ -35,6 +35,7 @@ FXDEFMAP(FontSelector) FontSelectorMap[] =
 FXIMPLEMENT(FontSelector, FXPacker, FontSelectorMap, ARRAYNUMBER(FontSelectorMap))
 
 
+// Construct
 FontSelector::FontSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint opts, int x, int y, int w, int h) :
     FXPacker(p, opts, x, y, w, h)
 {
@@ -97,7 +98,7 @@ FontSelector::FontSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
 
     // Character set choice
     new FXLabel(attributes, _("Character Set:"), NULL, LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
-    charset = new ComboBox(attributes, 8, this, ID_CHARSET, COMBOBOX_STATIC | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
+    charset = new ComboBox(attributes, 8, false, false, this, ID_CHARSET, COMBOBOX_STATIC | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
     charset->setNumVisible(10);
     charset->appendItem(_("Any"), (void*)0);
     charset->appendItem(_("West European"), (void*)FONTENCODING_WESTEUROPE);
@@ -129,7 +130,7 @@ FontSelector::FontSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
 
     // Set width
     new FXLabel(attributes, _("Set Width:"), NULL, LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
-    setwidth = new ComboBox(attributes, 9, this, ID_SETWIDTH, COMBOBOX_STATIC | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
+    setwidth = new ComboBox(attributes, 9, false, false, this, ID_SETWIDTH, COMBOBOX_STATIC | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
     setwidth->setNumVisible(10);
     setwidth->appendItem(_("Any"), (void*)0);
     setwidth->appendItem(_("Ultra condensed"), (void*)FXFont::UltraCondensed);
@@ -145,7 +146,7 @@ FontSelector::FontSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
 
     // Pitch
     new FXLabel(attributes, _("Pitch:"), NULL, LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
-    pitch = new ComboBox(attributes, 5, this, ID_PITCH, COMBOBOX_STATIC | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
+    pitch = new ComboBox(attributes, 5, false, false, this, ID_PITCH, COMBOBOX_STATIC | LAYOUT_CENTER_Y | LAYOUT_FILL_COLUMN);
     pitch->setNumVisible(3);
     pitch->appendItem(_("Any"), (void*)0);
     pitch->appendItem(_("Fixed"), (void*)FXFont::Fixed);
