@@ -12,13 +12,16 @@
 #include "FileDialog.h"
 #include "HistInputDialog.h"
 
+
+// Global variables
 extern FXString homedir;
 
+
 // Object implementation
 FXIMPLEMENT(HistComboBox, ComboBox, NULL, 0)
 
-HistComboBox::HistComboBox(FXComposite* p, int cols, FXObject* tgt, FXSelector sel, FXuint opts) :
-    ComboBox(p, cols, tgt, sel, opts)
+HistComboBox::HistComboBox(FXComposite* p, int cols, FXbool addr, FXbool clrbtn, FXObject* tgt, FXSelector sel, FXuint opts) :
+    ComboBox(p, cols, addr, clrbtn, tgt, sel, opts)
 {
 }
 
@@ -34,6 +37,7 @@ FXDEFMAP(HistInputDialog) HistInputDialogMap[] =
 {
     FXMAPFUNC(SEL_KEYPRESS, 0, HistInputDialog::onCmdKeyPress),
     FXMAPFUNC(SEL_COMMAND, HistInputDialog::ID_BROWSE_PATH, HistInputDialog::onCmdBrowsePath),
+    FXMAPFUNC(SEL_UPDATE, HistInputDialog::ID_ACCEPT, HistInputDialog::onUpdAccept),
 };
 
 
@@ -42,7 +46,7 @@ FXIMPLEMENT(HistInputDialog, DialogBox, HistInputDialogMap, ARRAYNUMBER(HistInpu
 
 // Construct a dialog box with an optional check box
 HistInputDialog::HistInputDialog(FXWindow* w, FXString inp, FXString message, FXString title, FXString label,
-                                 FXIcon* ic, FXuint browse, FXbool option, FXString optiontext) :
+                                 FXIcon* ic, FXbool addr, FXbool clrbtn, FXuint browse, FXbool option, FXString optiontext) :
     DialogBox(w, title, DECOR_TITLE | DECOR_BORDER | DECOR_STRETCHABLE | DECOR_MAXIMIZE | DECOR_CLOSE)
 {
     // Browse type flag
@@ -53,10 +57,10 @@ HistInputDialog::HistInputDialog(FXWindow* w, FXString inp, FXString message, FX
                                     5, 5);
 
     // Accept
-    new FXButton(buttons, _("&Accept"), NULL, this, ID_ACCEPT, FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
+    accept = new FXButton(buttons, _("&Accept"), NULL, this, ID_ACCEPT, FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
 
     // Cancel
-    new FXButton(buttons, _("&Cancel"), NULL, this, ID_CANCEL, FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
+    cancel = new FXButton(buttons, _("&Cancel"), NULL, this, ID_CANCEL, FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
 
     // Optional check box
     checkbutton = new FXHorizontalFrame(this, JUSTIFY_RIGHT | LAYOUT_SIDE_BOTTOM | LAYOUT_FILL_X, 0, 0, 0, 0, 10, 10, 0,
@@ -78,11 +82,11 @@ HistInputDialog::HistInputDialog(FXWindow* w, FXString inp, FXString message, FX
     // Label and input field (combo box)
     FXMatrix* matrix2 = new FXMatrix(contents, 3, MATRIX_BY_COLUMNS | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y);
     new FXLabel(matrix2, label, NULL, LAYOUT_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_ROW);
-    input = new HistComboBox(matrix2, 40, NULL, 0, COMBOBOX_INSERT_LAST | LAYOUT_CENTER_Y | LAYOUT_CENTER_X |
+    input = new HistComboBox(matrix2, 40, addr, clrbtn, NULL, 0, COMBOBOX_INSERT_LAST | LAYOUT_CENTER_Y | LAYOUT_CENTER_X |
                              LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_FILL_X);
     input->setNumVisible(8);
     input->setText(inp);
-    new FXButton(matrix2, _("\tSelect destination..."), minifiledialogicon, this, ID_BROWSE_PATH, FRAME_GROOVE |
+    new FXButton(matrix2, _("\tSelect Destination..."), minifiledialogicon, this, ID_BROWSE_PATH, FRAME_GROOVE |
                  LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
     if (!xf_isutf8(message.text(), message.length()))
     {
@@ -145,19 +149,19 @@ long HistInputDialog::onCmdBrowsePath(FXObject* sender, FXSelector sel, void* pt
 
     if (browsetype == HIST_INPUT_FOLDER)
     {
-        title = _("Select a destination folder");
+        title = _("Select a Destination Folder");
     }
     else if (browsetype == HIST_INPUT_FILE)
     {
-        title = _("Select a file");
+        title = _("Select a File");
     }
     else if (browsetype == HIST_INPUT_EXECUTABLE_FILE)
     {
-        title = _("Select an executable file");
+        title = _("Select an Executable File");
     }
     else
     {
-        title = _("Select a file or a destination folder");
+        title = _("Select a File or a Destination Folder");
     }
 
     // File dialog
@@ -202,3 +206,19 @@ void HistInputDialog::setDirectory(const FXString& path)
 {
     initialdir = path;
 }
+
+
+// Update accept button
+long HistInputDialog::onUpdAccept(FXObject* sender, FXSelector sel, void* ptr)
+{
+    if (input->getText() == "")
+    {
+        accept->disable();
+    }
+    else
+    {
+        accept->enable();
+    }
+    
+    return 1;    
+}
