@@ -35,7 +35,8 @@ public:
         field->setFocus();
     }
 
-    HistComboBox(FXComposite* p, int cols, FXObject* tgt = NULL, FXSelector sel = 0, FXuint opts = COMBOBOX_NORMAL);
+    HistComboBox(FXComposite* p, int cols, FXbool addr = false, FXbool crlbtn = false, FXObject* tgt = NULL,
+                 FXSelector sel = 0, FXuint opts = COMBOBOX_NORMAL);
     virtual void create();
 };
 
@@ -45,6 +46,8 @@ class HistInputDialog : public DialogBox
 protected:
     FXHorizontalFrame* buttons = NULL;
     FXHorizontalFrame* checkbutton = NULL;
+    FXButton* accept = NULL;
+    FXButton* cancel = NULL;
     HistComboBox* input = NULL;
     FXuint browsetype = 0;
     FXString initialdir;
@@ -59,11 +62,14 @@ public:
         ID_LAST
     };
     HistInputDialog(FXWindow*, FXString, FXString, FXString, FXString label = "", FXIcon* ic = NULL,
-                    FXuint browse = HIST_INPUT_FILE, FXbool option = false, FXString = FXString::null);
+                    FXbool addr = false, FXbool clrbtn = false, FXuint browse = HIST_INPUT_FILE,
+                    FXbool option = false, FXString = FXString::null);
     virtual void create();
 
     long onCmdKeyPress(FXObject*, FXSelector, void*);
     long onCmdBrowsePath(FXObject*, FXSelector, void*);
+    long onUpdAccept(FXObject*, FXSelector, void*);
+
     FXString getText()
     {
         return input->getText();
