@@ -25,7 +25,7 @@ enum
     */
     ICONLIST_SEARCH            = 0x10000000,           // Icon list is a search list (must be same value as in FileList)
     ICONLIST_STANDARD          = 0x20000000,           // Icon list is a not a file list and not a search list
-    ICONLISTFILELIST           = 0x40000000,           // Icon list is a file list
+    ICONLIST_FILELIST          = 0x40000000,           // Icon list is a file list
 };
 
 
@@ -211,42 +211,42 @@ class FXAPI IconList : public FXScrollArea
 {
     FXDECLARE(IconList)
 protected:
-    FXHeader* header = NULL;                                    // Header control
-    IconItemList items;                                         // Item list
-    int nrows = 0;                                              // Number of rows
-    int ncols = 0;                                              // Number of columns
-    int anchor = 0;                                             // Anchor item
-    int current = 0;                                            // Current item
-    int extent = 0;                                             // Extent item
-    int cursor = 0;                                             // Cursor item
-    int viewable = 0;                                           // Visible item
-    FXFont* font = NULL;                                        // Font
-    IconListSortFunc sortfunc = NULL;                           // Item sort function
-    FXColor textColor = FXRGB(0, 0, 0);                         // Text color
-    FXColor selbackColor = FXRGB(0, 0, 0);                      // Selected back color
-    FXColor seltextColor = FXRGB(0, 0, 0);                      // Selected text color
-    FXColor highlightColor = FXRGB(0, 0, 0);                    // Highlight color
-    FXColor sortColor = FXRGB(0, 0, 0);                         // Sort color
-    FXColor highlightSortColor = FXRGB(0, 0, 0);                // Highlight sort color
-    int itemWidth = 0;                                          // Item width
-    int itemHeight = 0;                                         // Item height
-    int itemSpace = 0;                                          // Space for item label
-    int anchorx = 0;                                            // Rectangular selection
+    FXHeader* header = NULL;                        // Header control
+    IconItemList items;                             // Item list
+    int nrows = 0;                                  // Number of rows
+    int ncols = 0;                                  // Number of columns
+    int anchor = 0;                                 // Anchor item
+    int current = 0;                                // Current item
+    int extent = 0;                                 // Extent item
+    int cursor = 0;                                 // Cursor item
+    int viewable = 0;                               // Visible item
+    FXFont* font = NULL;                            // Font
+    IconListSortFunc sortfunc = NULL;               // Item sort function
+    FXColor textColor = FXRGB(0, 0, 0);             // Text color
+    FXColor selbackColor = FXRGB(0, 0, 0);          // Selected back color
+    FXColor seltextColor = FXRGB(0, 0, 0);          // Selected text color
+    FXColor highlightColor = FXRGB(0, 0, 0);        // Highlight color
+    FXColor sortColor = FXRGB(0, 0, 0);             // Sort color
+    FXColor highlightSortColor = FXRGB(0, 0, 0);    // Highlight sort color
+    int itemWidth = 0;                              // Item width
+    int itemHeight = 0;                             // Item height
+    int itemSpace = 0;                              // Space for item label
+    int anchorx = 0;                                // Rectangular selection
     int anchory = 0;
     int currentx = 0;
     int currenty = 0;
-    int grabx = 0;                                              // Grab point x
-    int graby = 0;                                              // Grab point y
-    FXString lookup;                                            // Lookup string
-    FXString help;                                              // Help text
-    FXbool state = false;                                       // State of item
-    FXbool allowTooltip = false;                                // Allow tooltip in single click mode
-    FXuint numsortheader = 0;                                   // Index of the sorted column
-    double headerpct[10];                                       // Header sizes, relatively to the list width (in percent)
-    int count = 0;                                              // Counter used to properly initialize the relative header sizes
-    FXbool ignorecase = false;                                  // Case sensitivity for file name sorting
-    FXbool initheaderpct = false;                               // Indicates we have to initialize the headerpct for the deletion columns
-    double scalefrac = 1.0;                                     // Icon scaling factor
+    int grabx = 0;                                  // Grab point x
+    int graby = 0;                                  // Grab point y
+    FXString lookup;                                // Lookup string
+    FXString help;                                  // Help text
+    FXbool state = false;                           // State of item
+    FXbool allowTooltip = false;                    // Allow tooltip in single click mode
+    FXuint numsortheader = 0;                       // Index of the sorted column
+    double headerpct[10];                           // Header sizes, relatively to the list width (in percent)
+    int count = 0;                                  // Counter used to properly initialize the relative header sizes
+    FXbool ignorecase = false;                      // Case sensitivity for file name sorting
+    FXbool initheaderpct = false;                   // Indicates we have to initialize the headerpct for the deletion columns
+    double scalefrac = 1.0;                         // Icon scaling factor
 
     FXuint idCol[NMAX_COLS + 1] = { 0 };
     FXuint nbCols = 0;
@@ -349,8 +349,8 @@ public:
 public:
 
     // Construct icon list with no items in it initially
-    IconList(FXComposite* p, FXuint* ic, FXuint nc, FXObject* tgt = NULL, FXSelector sel = 0, FXuint opts = ICONLIST_NORMAL,
-             int x = 0, int y = 0, int w = 0, int h = 0);
+    IconList(FXComposite* p, FXuint* ic, FXuint nc, FXObject* tgt = NULL, FXSelector sel = 0,
+             FXuint opts = ICONLIST_NORMAL, int x = 0, int y = 0, int w = 0, int h = 0);
 
     // Create server-side resources
     virtual void create();
@@ -521,7 +521,7 @@ public:
     }
 
     // Return index of item at x,y, or -1 if none
-    virtual int getItemAt(int x, int y);
+    virtual int getItemAt(int x, int y, int state = -1);
 
     // Search items by name, beginning from item start.  If the start
     // item is -1 the search will start at the first item in the list.
