@@ -259,14 +259,14 @@ long MessageBox::onCmdSu(FXObject* sender, FXSelector sel, void*)
         // sudo
         if (root_auth == 1)
         {
-            title = _("Enter the user password:");
+            title = _("Enter user password:");
             FXString sudo_cmd = getApp()->reg().readStringEntry("OPTIONS", "sudo_cmd", DEFAULT_SUDO_CMD);
             cmd = " -g 60x4 -e " + sudo_cmd;
         }
         // su
         else if (root_auth == 2)
         {
-            title = _("Enter the root password:");
+            title = _("Enter root password:");
             FXString su_cmd = getApp()->reg().readStringEntry("OPTIONS", "su_cmd", DEFAULT_SU_CMD);
             cmd = " -g 60x4 -e " + su_cmd;
         }
