@@ -9,14 +9,14 @@
 FXDEFMAP(PathLinker) PathLinkerMap[] =
 {
     FXMAPFUNC(SEL_FOCUSIN, PathLinker::ID_FOCUS_BUTTON, PathLinker::onCmdFocusButton),
-    FXMAPFUNCS(SEL_LEFTBUTTONPRESS, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::pathButtonPressed),
+    FXMAPFUNCS(SEL_COMMAND, PathLinker::ID_START_LINK, PathLinker::ID_END_LINK, PathLinker::onCmdLinkButton),
     FXMAPFUNC(SEL_UPDATE, 0, PathLinker::onUpdPath),
 };
 
 FXIMPLEMENT(PathLinker, FXHorizontalFrame, PathLinkerMap, ARRAYNUMBER(PathLinkerMap))
 
 
-// Construct object
+// Construct
 PathLinker::PathLinker(FXComposite* a, FileList* flist, DirList* dlist, FXuint opts) :
     FXHorizontalFrame(a, opts, 0, 0, 0, 0, 0, 0, 2,2, 2, 2)
 {
@@ -171,7 +171,7 @@ void PathLinker::setPath(FXString text)
 }
 
 
-// Update current path according to the clicked button
+// Update current path according to the clicked link button
 void PathLinker::updatePath(FXString text, FXuint index)
 {
     // Remove trailing /
@@ -220,6 +220,7 @@ void PathLinker::updatePath(FXString text, FXuint index)
 }
 
 
+// Change link button text
 void PathLinker::setText(FXuint index, FXString displayText)
 {
     if (index < NMAX_LINKS)
@@ -240,8 +241,8 @@ void PathLinker::setText(FXuint index, FXString displayText)
 }
 
 
-// Button was pressed
-long PathLinker::pathButtonPressed(FXObject* sender, FXSelector sel, void* ptr)
+// Link button was pressed
+long PathLinker::onCmdLinkButton(FXObject* sender, FXSelector sel, void* ptr)
 {
     // Set the focus on the file list
     filelist->setFocus();
