@@ -46,7 +46,7 @@ public:
     virtual void create();
 
     virtual ~PathLinker();
-    long pathButtonPressed(FXObject*, FXSelector, void*);
+    long onCmdLinkButton(FXObject*, FXSelector, void*);
     long onCmdFocusButton(FXObject*, FXSelector, void*);
     long onUpdPath(FXObject*, FXSelector, void*);
     void setPath(FXString);
