@@ -342,8 +342,6 @@ MountsList::MountsList(FXWindow* owner, FXComposite* p, FXObject* tgt, FXSelecto
             // Samba share
             if (mounttype == "smb-share")
             {
-                // Get mount name
-
                 FXString tmp;
                 int pos = 0;
 
@@ -357,7 +355,31 @@ MountsList::MountsList(FXWindow* owner, FXComposite* p, FXObject* tgt, FXSelecto
                 tmp = gvfsname.right(gvfsname.length() - pos);
                 FXString share = tmp.before(',');
 
-                FXString name = share + "@" + server;
+                // Mount name and path
+                FXString name = share.substitute("%20", " ") + "@" + server;
+                FXString pathname = gvfspath + PATHSEPSTRING + gvfsname;
+                mounts->insert(name.text(), pathname.text());
+                FXList::appendItem(name, mininetdriveicon);
+            }
+
+            // SSH mount
+            if (mounttype == "sftp")
+            {
+                FXString tmp;
+                int pos = 0;
+
+                // Host name
+                pos = gvfsname.find("host=") + 5;
+                tmp = gvfsname.right(gvfsname.length() - pos);
+                FXString host = tmp.before(',');
+
+                // User name
+                pos = gvfsname.find("user=") + 5;
+                tmp = gvfsname.right(gvfsname.length() - pos);
+                FXString user = tmp.before(',');
+
+                // Mount name and path
+                FXString name = user.substitute("%20", " ") + "@" + host;
                 FXString pathname = gvfspath + PATHSEPSTRING + gvfsname;
                 mounts->insert(name.text(), pathname.text());
                 FXList::appendItem(name, mininetdriveicon);
@@ -370,6 +392,7 @@ MountsList::MountsList(FXWindow* owner, FXComposite* p, FXObject* tgt, FXSelecto
                 FXString name = gvfsname.after('_');
                 name = name.before('_', 2);
 
+                // Mount name and path
                 FXString pathname = gvfspath + PATHSEPSTRING + gvfsname;
                 mounts->insert(name.text(), pathname.text());
                 FXList::appendItem(name, miniremovabledeviceicon);
@@ -551,6 +574,29 @@ long MountsList::onMountsRefresh(FXObject* sender, FXSelector, void* ptr)
                     FXList::appendItem(name, mininetdriveicon);
                 }
 
+                // SSH mount
+                if (mounttype == "sftp")
+                {
+                    FXString tmp;
+                    int pos = 0;
+
+                    // Host name
+                    pos = gvfsname.find("host=") + 5;
+                    tmp = gvfsname.right(gvfsname.length() - pos);
+                    FXString host = tmp.before(',');
+
+                    // User name
+                    pos = gvfsname.find("user=") + 5;
+                    tmp = gvfsname.right(gvfsname.length() - pos);
+                    FXString user = tmp.before(',');
+
+                    // Mount name and path
+                    FXString name = user.substitute("%20", " ") + "@" + host;
+                    FXString pathname = gvfspath + PATHSEPSTRING + gvfsname;
+                    mounts->insert(name.text(), pathname.text());
+                    FXList::appendItem(name, mininetdriveicon);
+                }
+
                 // MTP device
                 if (mounttype == "mtp")
                 {
