@@ -12,23 +12,25 @@
 // Number of modifiable colors
 #define NUM_COLORS    12
 
-// Number of themes
-#define NUM_THEMES    9
+// Number of default themes
+#define NUM_DEFAULT_THEMES    9
 
 
 struct Theme
 {
-    FXString    name;
-    FXString    tip;
-    FXColor    color[NUM_COLORS];
-    Theme(){
+    FXString name;
+    FXString tip;
+    FXColor color[NUM_COLORS];
+    Theme()
+    {
         name = "";
         tip = "";
     }
 
     Theme(const char* n, const char* t, FXColor base = 0, FXColor bdr = 0, FXColor bg = 0, FXColor fg = 0,
           FXColor selbg = 0, FXColor selfg = 0, FXColor listbg = 0, FXColor listfg = 0,
-          FXColor listhl = 0, FXColor pbarfg = 0, FXColor attenfg = 0, FXColor scrollfg = 0){
+          FXColor listhl = 0, FXColor pbarfg = 0, FXColor attenfg = 0, FXColor scrollfg = 0)
+    {
         name = FXString(n);
         tip = FXString(t);
         color[0] = base;
@@ -49,6 +51,11 @@ struct Theme
 };
 
 
+// Vector of themes
+typedef std::vector<Theme>   vector_Theme;
+
+
+
 class PreferencesBox : public DialogBox
 {
     FXDECLARE(PreferencesBox)
@@ -73,6 +80,9 @@ private:
     FXTextField* textfont = NULL;
     FXTextField* mountcmd = NULL;
     FXTextField* umountcmd = NULL;
+#if defined(linux) && defined(XFE_AUTOMOUNTER)
+    FXGroupBox* automountgroup = NULL;
+#endif
     FXGroupBox* rootgroup = NULL;
     FXLabel* sulabel = NULL;
     FXLabel* sudolabel = NULL;
@@ -101,7 +111,14 @@ private:
     FXCheckButton* fileopen = NULL;
     FXCheckButton* filetooltips = NULL;
     FXCheckButton* relativeresize = NULL;
+    FXCheckButton* alwaysshowtabbar = NULL;
+    FXCheckButton* restoretabs = NULL;
     FXCheckButton* showpathlink = NULL;
+#if defined(linux) && defined(XFE_AUTOMOUNTER)
+    FXCheckButton* automountbutton = NULL;
+    FXCheckButton* autoopenbutton = NULL;
+    FXLabel* automountlabel = NULL;
+#endif
     FXCheckButton* rootmode = NULL;
     FXCheckButton* trashcan = NULL;
     FXCheckButton* trashbypass = NULL;
@@ -130,8 +147,11 @@ private:
     FXSpinner* bigthumb_spin = NULL;
     FXSpinner* minithumb_spin = NULL;
     FXDataTarget startdirtarget;
-    int startdirmode = 0;
-    int oldstartdirmode = 0;
+    FXDataTarget newtabdirtarget;
+    FXuint startdirmode = 0;
+    FXuint oldstartdirmode = 0;
+    FXuint newtabdirmode = 0;
+    FXuint oldnewtabdirmode = 0;
 #ifdef STARTUP_NOTIFICATION
     FXCheckButton* usesn = NULL;
 #endif
@@ -163,7 +183,7 @@ private:
     FXuint nbCols_prev = 0;
 
     ColorWell* cwell = NULL;
-    Theme Themes[NUM_THEMES];
+    vector_Theme Themes;
     Theme currTheme;
     Theme currTheme_prev;
     FXuint root_auth = 0;
@@ -176,7 +196,8 @@ private:
     FXbool fileopen_prev = false;
     FXbool filetooltips_prev = false;
     FXbool relativeresize_prev = false;
-    FXbool show_pathlink = false;
+    FXbool alwaysshowtabbar_prev = false;
+    FXbool restoretabs_prev = false;
     FXbool show_pathlink_prev = false;
     FXuint wheellines_prev = 0;
     FXint scrollbarsize_prev = 0;
@@ -188,6 +209,10 @@ private:
     FXbool del_emptydir_prev = false;
     FXbool overwrite_prev = false;
     FXbool exec_prev = false;
+#if defined(linux) && defined(XFE_AUTOMOUNTER)
+    FXbool automount_prev = false;
+    FXbool autoopen_prev = false;
+#endif
     FXbool rootmode_prev = false;
     FXString sudocmd_prev;
     FXString sucmd_prev;
@@ -244,9 +269,12 @@ public:
         ID_BROWSE_MOUNTCMD,
         ID_BROWSE_UMOUNTCMD,
         ID_COLOR,
+        ID_THEME,
+        ID_THEME_SAVEAS,
+        ID_THEME_RENAME,
+        ID_THEME_REMOVE,
         ID_NORMALFONT,
         ID_TEXTFONT,
-        ID_THEME,
         ID_BROWSE_ICON_PATH,
         ID_TRASH_BYPASS,
         ID_CONFIRM_TRASH,
@@ -259,6 +287,7 @@ public:
         ID_WHEELADJUST,
         ID_SCROLLBARSIZE,
         ID_MOUNT_TIMEOUT,
+        ID_AUTO_OPEN,
         ID_UIDPI,
         ID_SINGLE_CLICK_FILEOPEN,
         ID_EXEC_TEXT_FILES,
@@ -270,6 +299,11 @@ public:
         ID_START_HOMEDIR,
         ID_START_CURRENTDIR,
         ID_START_LASTDIR,
+        ID_NEWTAB_HOMEDIR,
+        ID_NEWTAB_CURRENTDIR,
+        ID_NEWTAB_ROOTDIR,
+        ID_SHOW_TABBAR,
+        ID_RESTORE_TABS,
         ID_DIRPANEL_PLACES_TREE,
         ID_DIRPANEL_PLACES,
         ID_DIRPANEL_TREE,
@@ -291,14 +325,15 @@ public:
 
     FXuint execute(FXuint);
 
-    // Display tooltip for themes list
-    long onQueryTip(FXObject*, FXSelector, void*);
-
     long onCmdAccept(FXObject*, FXSelector, void*);
     long onCmdBrowse(FXObject*, FXSelector, void*);
     long onCmdColor(FXObject*, FXSelector, void*);
     long onUpdColor(FXObject*, FXSelector, void*);
+    long onCmdPopupMenu(FXObject*, FXSelector, void*);
     long onCmdTheme(FXObject*, FXSelector, void*);
+    long onCmdThemeSaveAs(FXObject*, FXSelector, void*);
+    long onCmdThemeRename(FXObject*, FXSelector, void*);
+    long onCmdThemeRemove(FXObject*, FXSelector, void*);
     long onCmdBrowsePath(FXObject*, FXSelector, void*);
     long onCmdNormalFont(FXObject*, FXSelector, void*);
     long onCmdTextFont(FXObject*, FXSelector, void*);
@@ -319,6 +354,8 @@ public:
     long onCmdRestoreKeyBindings(FXObject*, FXSelector, void*);
     long onCmdStartDir(FXObject*, FXSelector, void*);
     long onUpdStartDir(FXObject*, FXSelector, void*);
+    long onCmdNewTabDir(FXObject*, FXSelector, void*);
+    long onUpdNewTabDir(FXObject*, FXSelector, void*);
     long onCmdCopySuffixPos(FXObject*, FXSelector, void*);
     long onUpdCopySuffixPos(FXObject*, FXSelector, void*);
     long onCmdDirPanelStartup(FXObject*, FXSelector, void*);
@@ -329,5 +366,11 @@ public:
     long onCmdColDown(FXObject*, FXSelector, void*);
     long onCmdViewCol(FXObject*, FXSelector, void*);
     long onUpdListColUpDown(FXObject*, FXSelector, void*);
+#if defined(linux) && defined(XFE_AUTOMOUNTER)
+    long onUpdAutoOpen(FXObject*, FXSelector, void*);
+#endif
+
+    // Display tooltip for themes list
+    long onQueryTip(FXObject*, FXSelector, void*);
 };
 #endif
