@@ -34,11 +34,11 @@
 #include "Properties.h"
 
 
-
 // Global variables
 extern FXMainWindow* mainWindow;
 extern FXStringDict* fsdevices;
 extern FXString xdgdatahome;
+extern FXString execpath;
 
 
 // Map
@@ -78,10 +78,10 @@ PermsFrame::PermsFrame(FXComposite* parent, FXObject* target) :
     FXGroupBox* group5 = new FXGroupBox(chmodframe, _("Owner"),
                                         GROUPBOX_TITLE_LEFT | FRAME_GROOVE | LAYOUT_FILL_X | LAYOUT_FILL_Y);
     new FXLabel(group5, _("User"));
-    user = new ComboBox(group5, 5, NULL, 0, COMBOBOX_STATIC | LAYOUT_FILL_X);
+    user = new ComboBox(group5, 5, false, false, NULL, 0, COMBOBOX_STATIC | LAYOUT_FILL_X);
     user->setNumVisible(5);
     new FXLabel(group5, _("Group"));
-    grp = new ComboBox(group5, 5, NULL, 0, COMBOBOX_STATIC | LAYOUT_FILL_X);
+    grp = new ComboBox(group5, 5, false, false, NULL, 0, COMBOBOX_STATIC | LAYOUT_FILL_X);
     grp->setNumVisible(5);
 
     // User names (sorted in ascending order)
@@ -259,7 +259,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path, FXbool
     new FXLabel(matrix, _("Open:"), NULL, JUSTIFY_LEFT | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_CENTER_Y);
     open = new FXTextField(matrix, 30, NULL, 0,
                            TEXTFIELD_NORMAL | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_FILL_X | LAYOUT_CENTER_Y);
-    new FXButton(matrix, _("\tSelect file..."), minifiledialogicon, this, ID_BROWSE_OPEN,
+    new FXButton(matrix, _("\tSelect File..."), minifiledialogicon, this, ID_BROWSE_OPEN,
                  FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_FILL_X | LAYOUT_CENTER_Y, 0, 0, 0, 0, 10, 10);
 
     int is_ar = false;
@@ -282,13 +282,13 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path, FXbool
 #if defined(linux)
     else if (extension == "rpm")
     {
-        editlbl = _("Install/Upgrade:");
+        editlbl = _("Install / Upgrade:");
     }
 #endif
     new FXLabel(matrix, viewlbl, NULL, JUSTIFY_LEFT | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_CENTER_Y);
     view = new FXTextField(matrix, 30, NULL, 0,
                            TEXTFIELD_NORMAL | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_FILL_X | LAYOUT_CENTER_Y);
-    new FXButton(matrix, _("\tSelect file..."), minifiledialogicon, this, ID_BROWSE_VIEW,
+    new FXButton(matrix, _("\tSelect File..."), minifiledialogicon, this, ID_BROWSE_VIEW,
                  FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_FILL_X | LAYOUT_CENTER_Y, 0, 0, 0, 0, 10, 10);
 
     if (!is_ar)
@@ -297,7 +297,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path, FXbool
         edit = new FXTextField(matrix, 30, NULL, 0,
                                TEXTFIELD_NORMAL | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_FILL_X |
                                LAYOUT_CENTER_Y);
-        new FXButton(matrix, _("\tSelect file..."), minifiledialogicon, this, ID_BROWSE_EDIT,
+        new FXButton(matrix, _("\tSelect File..."), minifiledialogicon, this, ID_BROWSE_EDIT,
                      FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_FILL_X | LAYOUT_CENTER_Y, 0, 0, 0, 0, 10, 10);
     }
     else
@@ -308,13 +308,13 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path, FXbool
     new FXLabel(matrix, _("Big Icon:"), NULL, JUSTIFY_LEFT | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_CENTER_Y);
     bigic = new FXTextField(matrix, 30, NULL, 0,
                             TEXTFIELD_NORMAL | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_FILL_X | LAYOUT_CENTER_Y);
-    bigicbtn = new FXButton(matrix, _("\tSelect file..."), minifiledialogicon, this, ID_BIG_ICON,
+    bigicbtn = new FXButton(matrix, _("\tSelect File..."), minifiledialogicon, this, ID_BIG_ICON,
                             FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_FILL_X | LAYOUT_CENTER_Y, 0, 0, 0, 0, 10, 10);
 
     new FXLabel(matrix, _("Mini Icon:"), NULL, JUSTIFY_LEFT | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_CENTER_Y);
     miniic = new FXTextField(matrix, 30, NULL, 0,
                              TEXTFIELD_NORMAL | LAYOUT_FILL_COLUMN | LAYOUT_FILL_ROW | LAYOUT_FILL_X | LAYOUT_CENTER_Y);
-    miniicbtn = new FXButton(matrix, _("\tSelect file..."), minifiledialogicon, this, ID_MINI_ICON,
+    miniicbtn = new FXButton(matrix, _("\tSelect File..."), minifiledialogicon, this, ID_MINI_ICON,
                              FRAME_GROOVE | LAYOUT_FILL_X | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 10, 10);
 
     // File name
@@ -535,7 +535,8 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path, FXbool
             }
 
             // Load big and mini icons
-            FXString iconpath = getApp()->reg().readStringEntry("SETTINGS", "iconpath", DEFAULTICONPATH);
+            FXString defaulticonpath = xf_realpath(FXPath::directory(execpath) + "/../share/xfe/icons/default-theme");
+            FXString iconpath = xf_realpath(getApp()->reg().readStringEntry("SETTINGS", "iconpath", defaulticonpath.text()));
 
             FXIcon* bigicon = xf_loadiconfile(getApp(), iconpath, bigic->getText(), scalefrac, getApp()->getBaseColor());
             if (bigicon)
@@ -691,7 +692,7 @@ PropertiesBox::PropertiesBox(FXWindow* win, FXString file, FXString path, FXbool
     // Properties are different for mount points
     if (isMountpoint)
     {
-        FXGroupBox* mtgroup = new FXGroupBox(generalframe, _("Mount point"),
+        FXGroupBox* mtgroup = new FXGroupBox(generalframe, _("Mount Point"),
                                              GROUPBOX_TITLE_LEFT | FRAME_GROOVE | LAYOUT_FILL_X);
         FXMatrix* mtmatrix = new FXMatrix(mtgroup, 2, MATRIX_BY_COLUMNS | LAYOUT_FILL_X | LAYOUT_FILL_Y);
         new FXLabel(mtmatrix, _("Mount type:"), NULL, LAYOUT_LEFT | JUSTIFY_LEFT);
@@ -1497,7 +1498,7 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* sender, FXSelector sel, void* pt
         else
         {
             File* f;
-            f = new File(this, _("Rename files"), RENAME);
+            f = new File(this, _("Rename Files"), RENAME);
             f->create();
             f->rename(sourcepath, targetpath);
             delete f;
@@ -1994,10 +1995,10 @@ long PropertiesBox::onCmdCheck(FXObject* sender, FXSelector sel, void* ptr)
 
 long PropertiesBox::onCmdBrowse(FXObject* sender, FXSelector sel, void* ptr)
 {
-    FileDialog browseProgram(this, _("Select an executable file"));
+    FileDialog browseProgram(this, _("Select an Executable File"));
     const char* patterns[] =
     {
-        _("All files"), "*", NULL
+        _("All Files"), "*", NULL
     };
 
     browseProgram.setFilename(ROOTDIR);
@@ -2041,7 +2042,8 @@ long PropertiesBox::onCmdBrowseIcon(FXObject* sender, FXSelector sel, void* ptr)
         icon = miniic->getText();
     }
 
-    FXString iconpath = getApp()->reg().readStringEntry("SETTINGS", "iconpath", DEFAULTICONPATH);
+    FXString defaulticonpath = xf_realpath(FXPath::directory(execpath) + "/../share/xfe/icons/default-theme");
+    FXString iconpath = xf_realpath(getApp()->reg().readStringEntry("SETTINGS", "iconpath", defaulticonpath.text()));
     const char* patterns[] =
     {
         _("PNG Images"), "*.png",
