@@ -83,7 +83,7 @@ SearchWindow::SearchWindow(FXApp* app, const FXString& name, int x, int y, int w
     FXMatrix* matrix1 = new FXMatrix(searchframe, 4,
                                      MATRIX_BY_COLUMNS | LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y);
     new FXLabel(matrix1, _("Find files:"), NULL, LAYOUT_LEFT | LAYOUT_CENTER_Y | LAYOUT_FILL_ROW);
-    findfile = new HistComboBox(matrix1, 40, NULL, 0,
+    findfile = new HistComboBox(matrix1, 40, false, true, NULL, 0,
                                 COMBOBOX_INSERT_LAST | LAYOUT_CENTER_Y | LAYOUT_CENTER_X | LAYOUT_FILL_COLUMN |
                                 LAYOUT_FILL_ROW | LAYOUT_FILL_X);
     findfile->setNumVisible(5);
@@ -169,13 +169,13 @@ SearchWindow::SearchWindow(FXApp* app, const FXString& name, int x, int y, int w
 
     // User and group
     new FXLabel(matrix4, _("User:"), NULL, JUSTIFY_LEFT);
-    user = new ComboBox(matrix4, 15, NULL, 0, COMBOBOX_STATIC);
+    user = new ComboBox(matrix4, 15,false, false, NULL, 0, COMBOBOX_STATIC);
     user->setNumVisible(5);
     userbtn = new FXCheckButton(matrix4, FXString(" ") + _("\tFilter by user name"), NULL, 0,
                                 JUSTIFY_LEFT | LAYOUT_CENTER_Y);
 
     new FXLabel(matrix4, _("Group:"), NULL, JUSTIFY_LEFT);
-    grp = new ComboBox(matrix4, 15, NULL, 0, COMBOBOX_STATIC);
+    grp = new ComboBox(matrix4, 15, false, false, NULL, 0, COMBOBOX_STATIC);
     grp->setNumVisible(5);
     grpbtn = new FXCheckButton(matrix4, FXString(" ") + _("\tFilter by group name"), NULL, 0,
                                JUSTIFY_LEFT | LAYOUT_CENTER_Y);
@@ -212,7 +212,7 @@ SearchWindow::SearchWindow(FXApp* app, const FXString& name, int x, int y, int w
 
     // File type
     new FXLabel(matrix4, _("File type:"), NULL, JUSTIFY_LEFT);
-    type = new ComboBox(matrix4, 15, NULL, 0, COMBOBOX_STATIC);
+    type = new ComboBox(matrix4, 15, false, false, NULL, 0, COMBOBOX_STATIC);
     type->setNumVisible(5);
     type->appendItem(_("File"));
     type->appendItem(_("Folder"));
@@ -264,11 +264,11 @@ SearchWindow::SearchWindow(FXApp* app, const FXString& name, int x, int y, int w
     FXHorizontalFrame* buttons = new FXHorizontalFrame(frame2, PACK_UNIFORM_WIDTH, 0, 0, 0, 0, 10, 10, 5, 5);
 
     // Start
-    startbutton = new FXButton(buttons, _("&Start\tStart the search (F3)"), NULL, this, ID_START,
+    startbutton = new FXButton(buttons, _("&Start\tStart Search (F3)"), NULL, this, ID_START,
                                FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
 
     // Stop
-    stopbutton = new FXButton(buttons, _("&Stop\tStop the search (Esc)"), NULL, this, ID_STOP,
+    stopbutton = new FXButton(buttons, _("&Stop\tStop Search (Esc)"), NULL, this, ID_STOP,
                               FRAME_GROOVE | LAYOUT_RIGHT, 0, 0, 0, 0, 20, 20);
 
     // Quit
@@ -751,15 +751,18 @@ long SearchWindow::onCmdClose(FXObject*, FXSelector, void*)
 
     // Update history
     FindNum = 0;
-    for (int i = 0; i < findfile->getNumItems(); i++)
+    if (findfile->getNumItems() > 0)
     {
-        if (FindNum > FIND_HIST_SIZE - 1)
+        for (int i = 0; i < findfile->getNumItems(); i++)
         {
-            break;
+            if (FindNum > FIND_HIST_SIZE - 1)
+            {
+                break;
+            }
+            FXString str = findfile->getItemText(i);
+            xf_strlcpy(FindHistory[i], str.text(), str.length() + 1);
+            FindNum++;
         }
-        FXString str = findfile->getItemText(i);
-        xf_strlcpy(FindHistory[i], str.text(), str.length() + 1);
-        FindNum++;
     }
 
     // Set focus to main window
