@@ -207,7 +207,7 @@ public:
     }
 
     // Get header size given its index
-    int getHeaderSize(int index) const
+    int getHeaderSize(FXuint index) const
     {
         return searchpanel->getHeaderSize(index);
     }
