@@ -8,6 +8,7 @@
 #include <fx.h>
 
 #include "icons.h"
+#include "xfeutils.h"
 #include "TextWindow.h"
 
 
@@ -19,7 +20,7 @@ FXDEFMAP(TextWindow) TextWindowMap[] = {};
 FXIMPLEMENT(TextWindow, DialogBox, TextWindowMap, ARRAYNUMBER(TextWindowMap))
 
 
-// Construct Text dialog box
+// Construct
 TextWindow::TextWindow(FXWindow* owner, const FXString& name, int nblines, int nbcols) :
     DialogBox(owner, name, DECOR_TITLE | DECOR_BORDER | DECOR_STRETCHABLE | DECOR_MAXIMIZE | DECOR_CLOSE,
               0, 0, 0, 0, 6, 6, 6, 6, 4, 4)
@@ -30,6 +31,11 @@ TextWindow::TextWindow(FXWindow* owner, const FXString& name, int nblines, int n
                                     BUTTON_INITIAL | BUTTON_DEFAULT | LAYOUT_RIGHT | FRAME_GROOVE, 0, 0, 0, 0, 20, 20,
                                     5, 5);
 
+    // Add shortcut for closing window
+    FXString key = getApp()->reg().readStringEntry("KEYBINDINGS", "close", "Ctrl-W");
+    FXHotKey hotkey = xf_parseaccel(key);
+    getAccelTable()->addAccel(hotkey, this, FXSEL(SEL_COMMAND, DialogBox::ID_ACCEPT));
+
     // Text part
     FXHorizontalFrame* textbox = new FXHorizontalFrame(this,
                                                        LAYOUT_SIDE_TOP | LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_NONE,
@@ -53,6 +59,11 @@ TextWindow::TextWindow(FXApp* app, const FXString& name, int nblines, int nbcols
     FXButton* button = new FXButton(closebox, _("&Close"), NULL, this, DialogBox::ID_ACCEPT,
                                     BUTTON_INITIAL | BUTTON_DEFAULT | LAYOUT_RIGHT | FRAME_GROOVE, 0, 0, 0, 0, 20, 20,
                                     5, 5);
+    
+    // Add shortcut for closing window
+    FXString key = getApp()->reg().readStringEntry("KEYBINDINGS", "close", "Ctrl-W");
+    FXHotKey hotkey = xf_parseaccel(key);
+    getAccelTable()->addAccel(hotkey, this, FXSEL(SEL_COMMAND, DialogBox::ID_ACCEPT));
 
     // Text part
     FXHorizontalFrame* textbox = new FXHorizontalFrame(this,
