@@ -743,7 +743,7 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
 
     // Goto line
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "goto_line", "Ctrl-L");
-    new FXButton(toolbar, TAB + _("Goto line") + PARS(key) + TAB + _("Goto line number."), minigotoicon, this,
+    new FXButton(toolbar, TAB + _("Goto Line") + PARS(key) + TAB + _("Goto line number."), minigotoicon, this,
                  WriteWindow::ID_GOTO_LINE,
                  ICON_ABOVE_TEXT | BUTTON_TOOLBAR | FRAME_GROOVE | LAYOUT_CENTER_Y | LAYOUT_LEFT);
 
@@ -771,14 +771,14 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "search_prev", "Ctrl-Shift-G");
     new FXButton(toolbar,
-                 TAB + _("Search selection backward") + PARS(key) + TAB + _("Search backward for selected text.") +
+                 TAB + _("Search Selection Backward") + PARS(key) + TAB + _("Search backward for selected text.") +
                  PARS(key),
                  minisearchprevicon, this, WriteWindow::ID_SEARCH_BACK_SEL,
                  ICON_ABOVE_TEXT | BUTTON_TOOLBAR | FRAME_GROOVE | LAYOUT_CENTER_Y | LAYOUT_LEFT);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "search_next", "Ctrl-G");
     new FXButton(toolbar,
-                 TAB + _("Search selection forward") + PARS(key) + TAB + _("Search forward for selected text.") +
+                 TAB + _("Search Selection Forward") + PARS(key) + TAB + _("Search forward for selected text.") +
                  PARS(key),
                  minisearchnexticon, this, WriteWindow::ID_SEARCH_FORW_SEL,
                  ICON_ABOVE_TEXT | BUTTON_TOOLBAR | FRAME_GROOVE | LAYOUT_CENTER_Y | LAYOUT_LEFT);
@@ -788,14 +788,14 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
 
     // Preferences
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "word_wrap", "Ctrl-K");
-    new FXToggleButton(toolbar, TAB + _("Word wrap on") + PARS(key) + TAB + _("Set word wrap on.") + PARS(key),
-                       TAB + _("Word wrap off") + PARS(key) + TAB + _("Set word wrap off.") + PARS(key),
+    new FXToggleButton(toolbar, TAB + _("Word Wrap On") + PARS(key) + TAB + _("Set word wrap on.") + PARS(key),
+                       TAB + _("Word Wrap Off") + PARS(key) + TAB + _("Set word wrap off.") + PARS(key),
                        miniwrapofficon, miniwraponicon, this, ID_TOGGLE_WRAP,
                        BUTTON_TOOLBAR | LAYOUT_LEFT | ICON_BEFORE_TEXT);
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "line_numbers", "Ctrl-T");
-    new FXToggleButton(toolbar, TAB + _("Show line numbers") + PARS(key) + TAB + _("Show line numbers.") + PARS(key),
-                       TAB + _("Hide line numbers") + PARS(key) + TAB + _("Hide line numbers.") + PARS(key),
+    new FXToggleButton(toolbar, TAB + _("Show Line Numbers") + PARS(key) + TAB + _("Show line numbers.") + PARS(key),
+                       TAB + _("Hide Line Numbers") + PARS(key) + TAB + _("Hide line numbers.") + PARS(key),
                        minihidenumbersicon, minishownumbersicon, this, ID_TOGGLE_LINES_NUM,
                        BUTTON_TOOLBAR | LAYOUT_LEFT | ICON_BEFORE_TEXT);
 
@@ -895,19 +895,19 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
 
     new FXMenuSeparator(editmenu);
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "lower_case", "Ctrl-U");
-    text = _("Lo&wer-case") + TABS(key) + _("Change to lower case.") + PARS(key);
+    text = _("Lo&wercase") + TABS(key) + _("Change to lowercase.") + PARS(key);
     mc = new FXMenuCommand(editmenu, text, minilowercaseicon, editor, FXText::ID_LOWER_CASE);
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "upper_case", "Ctrl-Shift-U");
-    text = _("Upp&er-case") + TABS(key) + _("Change to upper case.") + PARS(key);
+    text = _("Upp&ercase") + TABS(key) + _("Change to uppercase.") + PARS(key);
     mc = new FXMenuCommand(editmenu, text, miniuppercaseicon, editor, FXText::ID_UPPER_CASE);
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "goto_line", "Ctrl-L");
-    text = _("&Goto line...") + TABS(key) + _("Goto line number.") + PARS(key);
+    text = _("&Goto Line...") + TABS(key) + _("Goto line number.") + PARS(key);
     mc = new FXMenuCommand(editmenu, text, minigotoicon, this, WriteWindow::ID_GOTO_LINE);
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
@@ -921,11 +921,10 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
     new FXMenuCommand(popupmenu, _("Cu&t"), minicuticon, editor, FXText::ID_CUT_SEL);
     new FXMenuCommand(popupmenu, _("&Paste"), minipasteicon, editor, FXText::ID_PASTE_SEL);
     new FXMenuCommand(popupmenu, _("Select &All"), NULL, editor, FXText::ID_SELECT_ALL);
-    new FXMenuSeparator(popupmenu);
 
     // View Menu entries
     new FXMenuCheck(viewmenu, _("&Toolbar") + TAB2 + _("Display toolbar."), toolbar, FXWindow::ID_TOGGLESHOWN);
-    new FXMenuCheck(viewmenu, _("&Status line") + TAB2 + _("Display status line."), statusbar,
+    new FXMenuCheck(viewmenu, _("&Status Line") + TAB2 + _("Display status line."), statusbar,
                     FXWindow::ID_TOGGLESHOWN);
 
     // Search Menu entries
@@ -942,13 +941,13 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "search_prev", "Ctrl-Shift-G");
-    text = _("Search sel. &backward") + TABS(key) + _("Search backward for selected text.") + PARS(key);
+    text = _("Search Sel. &Backward") + TABS(key) + _("Search backward for selected text.") + PARS(key);
     mc = new FXMenuCommand(searchmenu, text, minisearchprevicon, this, WriteWindow::ID_SEARCH_BACK_SEL);
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "search_next", "Ctrl-G");
-    text = _("Search sel. &forward") + TABS(key) + _("Search forward for selected text.") + PARS(key);
+    text = _("Search Sel. &Forward") + TABS(key) + _("Search forward for selected text.") + PARS(key);
     mc = new FXMenuCommand(searchmenu, text, minisearchnexticon, this, WriteWindow::ID_SEARCH_FORW_SEL);
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
@@ -956,13 +955,13 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
 
     // Preferences menu
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "word_wrap", "Ctrl-K");
-    text = _("&Word wrap") + TABS(key) + _("Toggle word wrap mode.") + PARS(key);
+    text = _("&Word Wrap") + TABS(key) + _("Toggle word wrap mode.") + PARS(key);
     mc = new FXMenuCheck(prefsmenu, text, this, ID_TOGGLE_WRAP);
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "line_numbers", "Ctrl-T");
-    text = _("&Line numbers") + TABS(key) + _("Toggle line numbers mode.") + PARS(key);
+    text = _("&Line Numbers") + TABS(key) + _("Toggle line numbers mode.") + PARS(key);
     mc = new FXMenuCheck(prefsmenu, text, this, ID_TOGGLE_LINES_NUM);
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
@@ -971,7 +970,7 @@ WriteWindow::WriteWindow(XFileWrite* a, const FXString& file, const FXbool _read
                     FXText::ID_TOGGLE_OVERSTRIKE);
     new FXMenuSeparator(prefsmenu);
     new FXMenuCommand(prefsmenu, _("&Font...") + TAB2 + _("Change text font."), minifontsicon, this, ID_FONT);
-    new FXMenuCommand(prefsmenu, _("&More preferences...") + TAB2 + _("Change other options."), miniprefsicon, this,
+    new FXMenuCommand(prefsmenu, _("&More Preferences...") + TAB2 + _("Change other options."), miniprefsicon, this,
                       ID_PREFERENCES);
 
     // Window menu
@@ -1175,7 +1174,7 @@ FXbool WriteWindow::loadFile(const FXString& file)
     // Opened file?
     if (!textfile.isOpen())
     {
-        MessageBox::error(this, BOX_OK, _("Error Loading File"), _("Unable to open file: %s"), file.text());
+        MessageBox::error(this, BOX_OK, _("Error"), _("Unable to open file: %s"), file.text());
         return false;
     }
 
@@ -1185,7 +1184,7 @@ FXbool WriteWindow::loadFile(const FXString& file)
     // Make buffer to load file
     if (!FXMALLOC(&text, char, size))
     {
-        MessageBox::error(this, BOX_OK, _("Error Loading File"), _("File is too big: %s (%d bytes)"), file.text(),
+        MessageBox::error(this, BOX_OK, _("Error"), _("File is too big: %s (%d bytes)"), file.text(),
                           size);
         return false;
     }
@@ -1263,13 +1262,13 @@ FXbool WriteWindow::saveFile(const FXString& file)
     // Unknown error
     if (space < 0)
     {
-        MessageBox::error(this, BOX_OK, _("Error Saving File"), _("Unable to save file: %s"), file.text());
+        MessageBox::error(this, BOX_OK, _("Error"), _("Unable to save file: %s"), file.text());
         return false;
     }
     // Not enough space left on file system to save the file
     else if (space < size)
     {
-        MessageBox::error(this, BOX_OK, _("Error Saving File"),
+        MessageBox::error(this, BOX_OK, _("Error"),
                           _("Not enough space left on device, unable to save file: %s\n\n\
 => To prevent losing data, you should save this file to another device before exiting!"),
                           file.text());
@@ -1282,14 +1281,14 @@ FXbool WriteWindow::saveFile(const FXString& file)
     // Opened file?
     if (!textfile.isOpen())
     {
-        MessageBox::error(this, BOX_OK, _("Error Saving File"), _("Unable to open file: %s"), file.text());
+        MessageBox::error(this, BOX_OK, _("Error"), _("Unable to open file: %s"), file.text());
         return false;
     }
 
     // Alloc buffer
     if (!FXMALLOC(&text, char, size + 1))
     {
-        MessageBox::error(this, BOX_OK, _("Error Saving File"), _("File is too big: %s"), file.text());
+        MessageBox::error(this, BOX_OK, _("Error"), _("File is too big: %s"), file.text());
         return false;
     }
 
@@ -1311,7 +1310,7 @@ FXbool WriteWindow::saveFile(const FXString& file)
     // Were we able to write it all?
     if (n != size)
     {
-        MessageBox::error(this, BOX_OK, _("Error Saving File"), _("File: %s truncated."), file.text());
+        MessageBox::error(this, BOX_OK, _("Error"), _("File: %s truncated."), file.text());
         return false;
     }
 
