@@ -18,8 +18,8 @@
 #include "icons.h"
 #include "xfeutils.h"
 #include "startupnotification.h"
-#include "FileDict.h"
 #include "FileDialog.h"
+#include "FileDict.h"
 #include "MessageBox.h"
 #include "CommandWindow.h"
 #include "XFileArchive.h"
@@ -35,6 +35,7 @@ char** args;
 FXString homedir;
 FXString xdgconfighome;
 FXString xdgdatahome;
+FXString execpath;
 
 // Integer UI scaling factor
 FXint scaleint = 1;
@@ -163,6 +164,7 @@ static const FXuchar hand3_mask_bits[] =
 FXDEFMAP(XFileArchive) XFileArchiveMap[] =
 {
     FXMAPFUNC(SEL_COMMAND, XFileArchive::ID_OPEN, XFileArchive::onCmdOpen),
+    FXMAPFUNC(SEL_COMMAND, XFileArchive::ID_RECENTFILE, XFileArchive::onCmdRecentFile),
     FXMAPFUNC(SEL_COMMAND, XFileArchive::ID_EXTRACT_TO, XFileArchive::onCmdExtractTo),
     FXMAPFUNC(SEL_COMMAND, XFileArchive::ID_EXTRACT, XFileArchive::onCmdExtract),
     FXMAPFUNC(SEL_COMMAND, XFileArchive::ID_ABOUT, XFileArchive::onCmdAbout),
@@ -188,7 +190,7 @@ FXDEFMAP(XFileArchive) XFileArchiveMap[] =
 // Object implementation
 FXIMPLEMENT(XFileArchive, FXMainWindow, XFileArchiveMap, ARRAYNUMBER(XFileArchiveMap))
 
-// Constructor
+// Construct
 XFileArchive::XFileArchive(FXApp* a) : FXMainWindow(a, "Xfa", NULL, NULL, DECOR_TITLE | DECOR_MINIMIZE |
                                                     DECOR_MAXIMIZE | DECOR_CLOSE | DECOR_BORDER | DECOR_STRETCHABLE)
 {
@@ -228,7 +230,7 @@ XFileArchive::XFileArchive(FXApp* a) : FXMainWindow(a, "Xfa", NULL, NULL, DECOR_
 
     // Toolbar button: File open
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "open", "Ctrl-O");
-    new FXButton(toolbar, TAB + _("Open archive file") + PARS(key), minifileopenicon, this,
+    new FXButton(toolbar, TAB + _("Open Archive File") + PARS(key), minifileopenicon, this,
                  ID_OPEN, style | FRAME_NONE | LAYOUT_CENTER_Y | LAYOUT_LEFT);
 
     // File Menu entries
@@ -240,6 +242,21 @@ XFileArchive::XFileArchive(FXApp* a) : FXMainWindow(a, "Xfa", NULL, NULL, DECOR_
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
+    // Recent file menu; this automatically hides if there are no files
+    FXMenuSeparator* sep1 = new FXMenuSeparator(filemenu);
+    sep1->setTarget(&mrufiles);
+    sep1->setSelector(FXRecentFiles::ID_ANYFILES);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_1);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_2);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_3);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_4);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_5);
+    new FXMenuCommand(filemenu, _("&Clear Recent Files") + TAB2 + _("Clear recent file menu."), NULL, &mrufiles,
+                      FXRecentFiles::ID_CLEAR);
+    FXMenuSeparator* sep2 = new FXMenuSeparator(filemenu);
+    sep2->setTarget(&mrufiles);
+    sep2->setSelector(FXRecentFiles::ID_ANYFILES);
+
     mc = new FXMenuCommand(filemenu, _("&Quit"), miniquiticon, this, ID_QUIT);
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "quit", "Ctrl-Q");
     mc->setAccelText(key);
@@ -296,6 +313,10 @@ XFileArchive::XFileArchive(FXApp* a) : FXMainWindow(a, "Xfa", NULL, NULL, DECOR_
         list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
     }
 
+    // Recent files
+    mrufiles.setTarget(this);
+    mrufiles.setSelector(ID_RECENTFILE);
+
     // Initialize archive path name
     archpathname = "";
 
@@ -364,29 +385,29 @@ long XFileArchive::onCmdOpen(FXObject*, FXSelector, void*)
     const char* patterns[] =
     {
         _("All Files"), "*",
-        _("tar.gz archives"), "*.tar.gz",
-        _("tgz archives"), "*.tgz",
-        _("gz archive"), "*.gz",
-        _("zip archives"), "*.zip",
-        _("jar archives"), "*.jar",
-        _("iso images"), "*.iso",
-        _("tar.bz2 archives"), "*.tar.bz2",
-        _("tbz2 archives"), "*.tbz2",
-        _("bz2 archives"), "*.bz2",
-        _("tar.xz archives"), "*.tar.xz",
-        _("txz archives"), "*.txz",
-        _("xz archives"), "*.xz",
-        _("tar.zst archives"), "*.tar.zst",
-        _("tzst archives"), "*.tzst",
-        _("zst archives"), "*.zst",
-        _("tar.Z archives"), "*.tar.Z",
-        _("taZ archives"), "*.taZ",
-        _("Z archives"), "*.Z",
-        _("7z archives"), "*.7z",
-        _("rar archives"), "*.rar",
-        _("lzh archives"), "*.lzh",
-        _("ace archives"), "*.ace",
-        _("arj archives"), "*.arj",
+        _("tar.gz Archives"), "*.tar.gz",
+        _("tgz Archives"), "*.tgz",
+        _("gz Archive"), "*.gz",
+        _("zip Archives"), "*.zip",
+        _("jar Archives"), "*.jar",
+        _("iso Images"), "*.iso",
+        _("tar.bz2 Archives"), "*.tar.bz2",
+        _("tbz2 Archives"), "*.tbz2",
+        _("bz2 Archives"), "*.bz2",
+        _("tar.xz Archives"), "*.tar.xz",
+        _("txz Archives"), "*.txz",
+        _("xz Archives"), "*.xz",
+        _("tar.zst Archives"), "*.tar.zst",
+        _("tzst Archives"), "*.tzst",
+        _("zst Archives"), "*.zst",
+        _("tar.Z Archives"), "*.tar.Z",
+        _("taZ Archives"), "*.taZ",
+        _("Z Archives"), "*.Z",
+        _("7z Archives"), "*.7z",
+        _("rar Archives"), "*.rar",
+        _("lzh Archives"), "*.lzh",
+        _("ace Archives"), "*.ace",
+        _("arj Archives"), "*.arj",
         NULL
     };
 
@@ -405,6 +426,7 @@ long XFileArchive::onCmdOpen(FXObject*, FXSelector, void*)
     if (opendialog.execute(PLACEMENT_OWNER))
     {
         archpathname = opendialog.getFilename();
+        mrufiles.appendFile(archpathname);
         readArchive();
     }
 
@@ -412,6 +434,16 @@ long XFileArchive::onCmdOpen(FXObject*, FXSelector, void*)
 }
 
 
+// Open recent file
+long XFileArchive::onCmdRecentFile(FXObject*, FXSelector, void* ptr)
+{
+    archpathname = (char*)ptr;
+    readArchive();
+
+    return 1;
+}
+
+
 // Extract archive to selected directory
 long XFileArchive::onCmdExtractTo(FXObject*, FXSelector, void*)
 {
@@ -490,7 +522,7 @@ long XFileArchive::onCmdExtractTo(FXObject*, FXSelector, void*)
     }
 
     // File selection dialog
-    FileDialog browse(this, _("Select a destination folder"));
+    FileDialog browse(this, _("Select a Destination Folder"));
     const char* patterns[] =
     {
         _("All Files"), "*", NULL
@@ -1014,7 +1046,7 @@ long XFileArchive::onCmdFileOpenWith(FXObject*, FXSelector, void*)
     if (opendialog == NULL)
     {
         opendialog = new HistInputDialog(this, "", _("Open selected file(s) with:"), _("Open With"), "",
-                                         bigfileopenicon, HIST_INPUT_EXECUTABLE_FILE, false);
+                                         bigfileopenicon, false, true, HIST_INPUT_EXECUTABLE_FILE, false);
     }
     opendialog->setText(cmd);
     opendialog->CursorEnd();
@@ -1101,6 +1133,12 @@ long XFileArchive::onCmdFileOpenWith(FXObject*, FXSelector, void*)
 
     getApp()->endWaitCursor();
 
+    // If list has been cleared, set history size to zero
+    if (opendialog->getHistorySize() == 0)
+    {
+        OpenNum = 0;
+    }
+
     return 1;
 }
 
@@ -1187,7 +1225,7 @@ long XFileArchive::onCmdFileExtractTo(FXObject*, FXSelector, void*)
     }
 
     // File selection dialog
-    FileDialog browse(this, _("Select a destination folder"));
+    FileDialog browse(this, _("Select a Destination Folder"));
     const char* patterns[] =
     {
         _("All Files"), "*", NULL
@@ -1281,10 +1319,7 @@ void XFileArchive::saveConfig()
         history += OpenHistory[i];
         history += ":";
     }
-    if (OpenNum)
-    {
-        getApp()->reg().writeStringEntry("HISTORY", "open", history.text());
-    }
+    getApp()->reg().writeStringEntry("HISTORY", "open", history.text());
 
     // Write filter history
     history = "";
@@ -1821,7 +1856,7 @@ long XFileArchive::onCmdPopupMenu(FXObject* sender, FXSelector sel, void* ptr)
 
             getRoot()->getCursorPosition(x, y, state);
 
-            new FXMenuCommand(menu, _("Open &with..."), minifileopenicon, this, XFileArchive::ID_FILE_OPEN_WITH);
+            new FXMenuCommand(menu, _("Open &With..."), minifileopenicon, this, XFileArchive::ID_FILE_OPEN_WITH);
             new FXMenuCommand(menu, _("&Open"), minifileopenicon, this, XFileArchive::ID_FILE_OPEN);
             new FXMenuCommand(menu, _("&Extract"), miniarchexticon, this, XFileArchive::ID_FILE_EXTRACT);
             new FXMenuCommand(menu, _("&Extract to..."), miniarchexticon, this, XFileArchive::ID_FILE_EXTRACT_TO);
@@ -2179,7 +2214,7 @@ int main(int argc, char* argv[])
     setlocale(LC_ALL, "");
 #endif
 
-#if ENABLE_NLS
+#ifdef ENABLE_NLS
     // Set the text message domain.
     bindtextdomain(PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(PACKAGE, "utf-8");
@@ -2244,8 +2279,9 @@ int main(int argc, char* argv[])
     application->setDefaultCursor(DEF_HAND_CURSOR, hand);
 
     // Load all application icons
-    FXbool iconpathfound = true;
-    loadicons = loadAppIcons(application, &iconpathfound);
+    FXuint iconpathstatus;
+    execpath = xf_execpath(argv[0]);
+    loadicons = loadAppIcons(application, &iconpathstatus);
 
     // Set base and border colors (to change the default colors at first run)
     FXColor basecolor = reg_xfe->readColorEntry("SETTINGS", "basecolor", FXRGB(237, 236, 235));
@@ -2297,18 +2333,28 @@ int main(int argc, char* argv[])
     // Create it
     application->create();
 
-    // Icon path not found
-    if (!iconpathfound)
+    // Icon path doesn't exist
+    if (iconpathstatus == ICONPATH_NOT_FOUND)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Icon path doesn't exist, icon theme was set back to default. Please check your icon path!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Icon path doesn't exist, default icon path was selected.\
+\n\nFrom Xfe, please check your icon path in Edit / Preferences / Appearance..."));
     }
 
     // Some icons not found
-    if (!loadicons)
+    if (!loadicons && iconpathstatus == ICONPATH_MISSING_ICONS)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Unable to load some icons. Please check your icon theme!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load some icons, default icon theme was selected.\
+\n\nFrom Xfe, please check your icon theme in Edit / Preferences / Appearance..."));       
+    }
+
+    // Default icon path doesn't exist
+    if (iconpathstatus == DEFAULTICONPATH_NOT_FOUND)
+    {
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load default icons, no icons can be shown.\
+\n\nPlease check your Xfe installation..."));       
     }
 
     // Tooltips setup time and duration
