@@ -135,7 +135,7 @@ public:
         ID_HARVEST,
         ID_QUIT,
         ID_RESTART,
-        IDFILELIST,
+        ID_FILELIST,
         ID_RECENTFILE,
         ID_ROTATE_90,
         ID_ROTATE_270,
