@@ -33,6 +33,7 @@ char** args;
 FXString homedir;
 FXString xdgconfighome;
 FXString xdgdatahome;
+FXString execpath;
 
 // Filter history
 char FilterHistory[FILTER_HIST_SIZE][MAX_PATTERN_SIZE];
@@ -158,6 +159,7 @@ FXDEFMAP(XFilePackage) XFilePackageMap[] =
 {
     FXMAPFUNC(SEL_SIGNAL, XFilePackage::ID_HARVEST, XFilePackage::onSigHarvest),
     FXMAPFUNC(SEL_CLOSE, 0, XFilePackage::onCmdQuit),
+    FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_RECENTFILE, XFilePackage::onCmdRecentFile),
     FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_QUIT, XFilePackage::onCmdQuit),
     FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_UNINSTALL, XFilePackage::onCmdUninstall),
     FXMAPFUNC(SEL_COMMAND, XFilePackage::ID_ABOUT, XFilePackage::onCmdAbout),
@@ -170,7 +172,7 @@ FXDEFMAP(XFilePackage) XFilePackageMap[] =
 // Object implementation
 FXIMPLEMENT(XFilePackage, FXMainWindow, XFilePackageMap, ARRAYNUMBER(XFilePackageMap))
 
-// Constructor
+// Construct
 XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL,
                                                     DECOR_TITLE | DECOR_MINIMIZE | DECOR_MAXIMIZE | DECOR_CLOSE |
                                                     DECOR_BORDER | DECOR_STRETCHABLE)
@@ -211,7 +213,7 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL,
 
     // Toolbar button: File open
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "open", "Ctrl-O");
-    new FXButton(toolbar, TAB + _("Open package file") + PARS(key), minifileopenicon, this, ID_OPEN,
+    new FXButton(toolbar, TAB + _("Open Package File") + PARS(key), minifileopenicon, this, ID_OPEN,
                  style | FRAME_NONE | LAYOUT_CENTER_Y | LAYOUT_LEFT);
 
     // File Menu entries
@@ -223,6 +225,21 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL,
     hotkey = xf_parseaccel(key);
     getAccelTable()->addAccel(hotkey, mc, FXSEL(SEL_COMMAND, FXMenuCommand::ID_ACCEL));
 
+    // Recent file menu; this automatically hides if there are no files
+    FXMenuSeparator* sep1 = new FXMenuSeparator(filemenu);
+    sep1->setTarget(&mrufiles);
+    sep1->setSelector(FXRecentFiles::ID_ANYFILES);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_1);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_2);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_3);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_4);
+    new FXMenuCommand(filemenu, FXString::null, NULL, &mrufiles, FXRecentFiles::ID_FILE_5);
+    new FXMenuCommand(filemenu, _("&Clear Recent Files") + TAB2 + _("Clear recent file menu."), NULL, &mrufiles,
+                      FXRecentFiles::ID_CLEAR);
+    FXMenuSeparator* sep2 = new FXMenuSeparator(filemenu);
+    sep2->setTarget(&mrufiles);
+    sep2->setSelector(FXRecentFiles::ID_ANYFILES);
+
     mc = new FXMenuCommand(filemenu, _("&Quit"), miniquiticon, this, ID_QUIT);
     key = getApp()->reg().readStringEntry("KEYBINDINGS", "quit", "Ctrl-Q");
     mc->setAccelText(key);
@@ -260,8 +277,8 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL,
     new FXButton(buttons, _("&Uninstall"), NULL, this, XFilePackage::ID_UNINSTALL,
                  FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
 
-    // Install/Upgrade
-    new FXButton(buttons, _("&Install/Upgrade"), NULL, this, XFilePackage::ID_INSTALL,
+    // Install / Upgrade
+    new FXButton(buttons, _("&Install / Upgrade"), NULL, this, XFilePackage::ID_INSTALL,
                  FRAME_GROOVE | LAYOUT_RIGHT | LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
 
     // Switcher
@@ -278,7 +295,7 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL,
     new FXTabItem(tabbook, _("File &List"), NULL);
     FXVerticalFrame* flistfr = new FXVerticalFrame(tabbook);
     p = new FXPacker(flistfr, LAYOUT_FILL_X | LAYOUT_FILL_Y | FRAME_NONE, 0, 0, 0, 0, 0, 0, 0, 0);
-    list = new FXTreeList(p, this, XFilePackage::IDFILELIST,
+    list = new FXTreeList(p, this, XFilePackage::ID_FILELIST,
                           LAYOUT_FILL_X | LAYOUT_FILL_Y | TREELIST_SHOWS_LINES | TREELIST_SINGLESELECT);
 
     // Initialize file name
@@ -288,6 +305,10 @@ XFilePackage::XFilePackage(FXApp* a) : FXMainWindow(a, "Xfp", NULL, NULL,
     smoothscroll = true;
     errorflag = false;
 
+    // Recent files
+    mrufiles.setTarget(this);
+    mrufiles.setSelector(ID_RECENTFILE);
+
     // Read settings
     save_win_pos = getApp()->reg().readUnsignedEntry("SETTINGS", "save_win_pos", false);
 }
@@ -328,9 +349,9 @@ long XFilePackage::onCmdOpen(FXObject*, FXSelector, void*)
     const char* patterns[] =
     {
         _("All Files"), "*",
-        _("RPM source packages"), "*.src.rpm",
-        _("RPM packages"), "*.rpm",
-        _("DEB packages"), "*.deb",
+        _("RPM Source Packages"), "*.src.rpm",
+        _("RPM Packages"), "*.rpm",
+        _("DEB Packages"), "*.deb",
         NULL
     };
 
@@ -343,6 +364,7 @@ long XFilePackage::onCmdOpen(FXObject*, FXSelector, void*)
     if (opendialog.execute(PLACEMENT_OWNER))
     {
         filename = opendialog.getFilename();
+        mrufiles.appendFile(filename);
         readDescription();
         readFileList();
     }
@@ -351,7 +373,18 @@ long XFilePackage::onCmdOpen(FXObject*, FXSelector, void*)
 }
 
 
-// Install/upgrade package
+// Open recent file
+long XFilePackage::onCmdRecentFile(FXObject*, FXSelector, void* ptr)
+{
+    filename = (char*)ptr;
+    readDescription();
+    readFileList();
+
+    return 1;
+}
+
+
+// Install / upgrade package
 long XFilePackage::onCmdInstall(FXObject*, FXSelector, void*)
 {
     FXString cmd;
@@ -384,7 +417,7 @@ long XFilePackage::onCmdInstall(FXObject*, FXSelector, void*)
     }
 
     // Make and show command window
-    CommandWindow* cmdwin = new CommandWindow(this, _("Install/Upgrade Package"), cmd, 10, 80);
+    CommandWindow* cmdwin = new CommandWindow(this, _("Install / Upgrade Package"), cmd, 10, 80);
     cmdwin->create();
 
     FXString msg;
@@ -675,7 +708,7 @@ void XFilePackage::start(FXString startpkg)
         FILE* fp = fopen(filename.text(), "r");
         if (!fp)
         {
-            MessageBox::error(this, BOX_OK, _("Error Loading File"), _("Unable to open file: %s"), filename.text());
+            MessageBox::error(this, BOX_OK, _("Error"), _("Unable to open file: %s"), filename.text());
             filename = "";
         }
         else
@@ -825,7 +858,7 @@ int main(int argc, char* argv[])
     setlocale(LC_ALL, "");
 #endif
 
-#if ENABLE_NLS
+#ifdef ENABLE_NLS
     // Set the text message domain.
     bindtextdomain(PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(PACKAGE, "utf-8");
@@ -890,8 +923,9 @@ int main(int argc, char* argv[])
     application->setDefaultCursor(DEF_HAND_CURSOR, hand);
 
     // Load all application icons
-    FXbool iconpathfound = true;
-    loadicons = loadAppIcons(application, &iconpathfound);
+    FXuint iconpathstatus;
+    execpath = xf_execpath(argv[0]);
+    loadicons = loadAppIcons(application, &iconpathstatus);
 
     // Set base and border colors (to change the default colors at first run)
     FXColor basecolor = reg_xfe->readColorEntry("SETTINGS", "basecolor", FXRGB(237, 236, 235));
@@ -943,18 +977,28 @@ int main(int argc, char* argv[])
     // Create it
     application->create();
 
-    // Icon path not found
-    if (!iconpathfound)
+    // Icon path doesn't exist
+    if (iconpathstatus == ICONPATH_NOT_FOUND)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Icon path doesn't exist, icon theme was set back to default. Please check your icon path!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Icon path doesn't exist, default icon path was selected.\
+\n\nFrom Xfe, please check your icon path in Edit / Preferences / Appearance..."));
     }
 
     // Some icons not found
-    if (!loadicons)
+    if (!loadicons && iconpathstatus == ICONPATH_MISSING_ICONS)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Unable to load some icons. Please check your icon theme!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load some icons, default icon theme was selected.\
+\n\nFrom Xfe, please check your icon theme in Edit / Preferences / Appearance..."));       
+    }
+
+    // Default icon path doesn't exist
+    if (iconpathstatus == DEFAULTICONPATH_NOT_FOUND)
+    {
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load default icons, no icons can be shown.\
+\n\nPlease check your Xfe installation..."));       
     }
 
     // Tooltips setup time and duration
