@@ -11,6 +11,7 @@ protected:
     FXMenuPane* filemenu = NULL;                    // File menu
     FXMenuPane* helpmenu = NULL;                    // Help menu
     FXMenuPane* prefsmenu = NULL;                   // Preferences menu
+    FXRecentFiles mrufiles;                         // Recent files
     FXToolBar* toolbar = NULL;                      // Toolbar
     FXString filename;                              // Current package name
     FXTreeList* list = NULL;                        // File list
@@ -29,7 +30,8 @@ public:
     enum
     {
         ID_DESCRIPTION=FXMainWindow::ID_LAST,
-        IDFILELIST,
+        ID_RECENTFILE,
+        ID_FILELIST,
         ID_UNINSTALL,
         ID_INSTALL,
         ID_ABOUT,
@@ -49,6 +51,7 @@ public:
         smoothscroll = smooth;
     }
 
+    long onCmdRecentFile(FXObject*, FXSelector, void*);
     long onCmdUninstall(FXObject*, FXSelector, void*);
     long onCmdInstall(FXObject*, FXSelector, void*);
     long onCmdAbout(FXObject*, FXSelector, void*);
