@@ -32,6 +32,7 @@
 FXString homedir;
 FXString xdgconfighome;
 FXString xdgdatahome;
+FXString execpath;
 
 // Integer UI scaling factor
 FXint scaleint = 1;
@@ -161,7 +162,7 @@ FXDEFMAP(XFileWrite) XFileWriteMap[] =
 FXIMPLEMENT(XFileWrite, FXApp, XFileWriteMap, ARRAYNUMBER(XFileWriteMap))
 
 
-// Make some windows
+// Construct
 XFileWrite::XFileWrite(const FXString& appname, const FXString& vdrname) : FXApp(appname, vdrname)
 {
     // If interrupt happens, quit gracefully; we may want to
@@ -257,7 +258,7 @@ int main(int argc, char* argv[])
     setlocale(LC_ALL, "");
 #endif
 
-#if ENABLE_NLS
+#ifdef ENABLE_NLS
     // Set the text message domain.
     bindtextdomain(PACKAGE, LOCALEDIR);
     bind_textdomain_codeset(PACKAGE, "utf-8");
@@ -298,8 +299,9 @@ int main(int argc, char* argv[])
     application->setDefaultCursor(DEF_HAND_CURSOR, hand);
 
     // Load all application icons
-    FXbool iconpathfound = true;
-    loadicons = loadAppIcons(application, &iconpathfound);
+    FXuint iconpathstatus;
+    execpath = xf_execpath(argv[0]);
+    loadicons = loadAppIcons(application, &iconpathstatus);
 
     // Set base and border colors (to change the default colors at first run)
     FXColor basecolor = reg_xfe->readColorEntry("SETTINGS", "basecolor", FXRGB(237, 236, 235));
@@ -344,18 +346,28 @@ int main(int argc, char* argv[])
     // Create application
     application->create();
 
-    // Icon path not found
-    if (!iconpathfound)
+    // Icon path doesn't exist
+    if (iconpathstatus == ICONPATH_NOT_FOUND)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Icon path doesn't exist, icon theme was set back to default. Please check your icon path!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Icon path doesn't exist, default icon path was selected.\
+\n\nFrom Xfe, please check your icon path in Edit / Preferences / Appearance..."));
     }
 
     // Some icons not found
-    if (!loadicons)
+    if (!loadicons && iconpathstatus == ICONPATH_MISSING_ICONS)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Unable to load some icons. Please check your icon theme!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load some icons, default icon theme was selected.\
+\n\nFrom Xfe, please check your icon theme in Edit / Preferences / Appearance..."));       
+    }
+
+    // Default icon path doesn't exist
+    if (iconpathstatus == DEFAULTICONPATH_NOT_FOUND)
+    {
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load default icons, no icons can be shown.\
+\n\nPlease check your Xfe installation..."));       
     }
 
     // Tooltips setup time and duration
