@@ -10,8 +10,8 @@
 \n \
                                   XFE, X File Explorer File Manager\n \
 \n \
-                                    <http:    //roland65.free.fr/xfe>\n \
-                                <http:    //sourceforge.net/projects/xfe>\n \
+                                    <http://roland65.free.fr/xfe>\n \
+                                <http://sourceforge.net/projects/xfe>\n \
 \n \
 \n \
 \n \
@@ -45,7 +45,9 @@
     - Commander/Explorer interface with four file manager modes : a) one panel, b) a folder tree\n \
       and one panel, c) two panels and d) a folder tree and two panels\n \
     - Horizontal or vertical file panels stacking\n \
+    - Dockable toolbars\n \
     - Panels synchronization and switching\n \
+    - Tabs\n \
     - Places panel with customizable bookmarks\n \
     - Customizable columns in detailed file list mode\n \
     - Integrated text editor and viewer (X File Write, Xfw)\n \
@@ -53,6 +55,8 @@
     - Integrated archive viewer and extractor (X File Archive, Xfa)\n \
     - Integrated package (rpm or deb) viewer / installer / uninstaller (X File Package, Xfp)\n \
     - Custom shell scripts (like Nautilus scripts)\n \
+    - Mount/Unmount devices with optional automounter (Linux only, supports MTP devices)\n \
+    - Managing network shares (Windows shares or connecting to SSH server)\n \
     - Search files and directories\n \
     - Bulk rename files\n \
     - Natural sort order (foo10.txt comes after foo2.txt...)\n \
@@ -65,14 +69,14 @@
     - Double click or single click file and folder navigation\n \
     - Mouse right click pop-up menu in tree list and file list\n \
     - Change file attributes\n \
-    - Mount/Unmount devices (Linux only)\n \
+    - Customizable color themes (GNOME, KDE, XFCE, Dark, ...)\n \
     - Warn when mount point are not responding (Linux only)\n \
     - Back and forward history lists for folder navigation\n \
-    - Color themes (GNOME, KDE, XFCE, Dark, ...)\n \
+    - Customizable color themes (GNOME, KDE, XFCE, Dark, ...)\n \
     - Icon themes (Default, GNOME, KDE, XFCE, ...)\n \
     - Create archives (tar, zip, gzip, bzip2, xz, zst, 7z, ...)\n \
     - Extract archives (many formats are supported)\n \
-    - File comparison (through external tool)\n \
+    - File / folder comparison (through external tool, ex: meld)\n \
     - Tooltips with file properties\n \
     - Progress bars or dialogs for lengthy file operations\n \
     - Thumbnails image previews\n \
@@ -150,6 +154,8 @@
     * Delete files                      - Shift-Del\n \
     * Copy file names to clipboard      - Ctrl-Shift-N\n \
     * Empty trash can                   - Ctrl-Del\n \
+    * New Tab                           - Shift-F1\n \
+    * Connect to Server                 - Shift-F5\n \
 \n \
 \n \
  Below are the default X File Image key bindings. These key bindings are specific to the Xfi application.\n \
@@ -204,10 +210,8 @@
   Trash system\n \
   =-=-=-=-=-=-=\n \
 \n \
- Xfe implements a trash system that is fully compliant with the freedesktop.org\n \
- standards.\n \
- This allows the user to move files to the trash can and to restore files from within Xfe or your favorite\n \
- desktop.\n \
+ Xfe implements a trash system that is fully compliant with the freedesktop.org standards.\n \
+ This allows the user to move files to the trash can and to restore files from within Xfe or your favorite desktop.\n \
  Note that the trash files location is: ~/.local/share/Trash/files\n \
 \n \
 \n \
@@ -233,8 +237,8 @@
  customize Xfe (this is particularly true for the file associations) by hand editing because all the local options\n \
  are located in the same file.\n \
 \n \
- Default PNG icons are located in /usr/share/xfe/icons/default-theme or /usr/local/share/xfe/icons/default-theme, depending\n \
- on your installation. You can easily change the icon theme path in the Preferences dialog.\n \
+ Default PNG icons are located in /usr/share/xfe/icons/default-theme or /usr/local/share/xfe/icons/default-theme,\n \
+ depending on your installation. You can easily change the icon theme path in the Preferences dialog.\n \
 \n \
 \n \
 \n \
@@ -246,21 +250,41 @@
  HD (4K) monitors.\n \
 \n \
 \n \
+\n \
+  Dockable Toolbars\n \
+  =-=-=-=-=-=-=-=-=\n \
+\n \
+ Starting with version 2.1, toolbars can be docked to the four corners of the window and their positions are saved\n \
+ (Xfe only) if the Auto save layout option is enabled in Edit Preferences / General dialog. To dock a toolbar, \n \
+ left click on its handle and drag it to the destination corner, or right click on it and use the popup menu.\n \
+\n \
+\n \
 \n \
   Places\n \
   =-=-=-=\n \
 \n \
- Starting with version 2.0, the folder panel features two tabs: one is the classic Tree view and the other is a Places view.\n \
- This Places view allows to view desktop folders (home, downloads, documents, music, ...), of drive mounts, network shares\n \
- and user's bookmarks.\n \
+ Starting with version 2.0, the folder panel features two tabs: one is the classic Tree view and the other\n \
+ is a Places view. This Places view allows to view desktop folders (home, downloads, documents, music, ...), of\n \
+ drive mounts, network shares and user's bookmarks.\n \
 \n \
- Network shares mounted from the desktop using gvfs (GNOME or XFCE) appear in the Places view\n \
- and can be unmounted (KDE network shares are not supported). Mount points for removable devices also appear in the Places\n \
- view.\n \
+ Network shares mounted from the desktop using gvfs (GNOME or XFCE) appear in the Places view and can be unmounted\n \
+ (KDE network shares are not supported). Mount points for removable devices also appear in the Places view.\n \
 \n \
  Bookmarks can be added, removed and customized (order, name and icon) using a context menu.\n \
 \n \
- The Places view is optional as is also the Tree view (related settings are located in the Preferences / General dialog).\n \
+ The Places view is optional as is also the Tree view (related settings are located in the\n \
+ Preferences / General dialog).\n \
+\n \
+\n \
+\n \
+  Tabs\n \
+  =-=-=\n \
+\n \
+ Starting with version 2.1, it is possible to add tabs by pressing Shift-F1 or by clicking on the + icon of the tab\n \
+ toolbar. A right click on a tab displays a popup menu that offers to move a tab or close it.\n \
+\n \
+ The tab toolbar can be always shown or hidden if not used. Options related to tabs usage can be found in the\n \
+ Edit / Preferences / Settings dialog.\n \
 \n \
 \n \
 \n \
@@ -338,6 +362,42 @@
  Multilingual Unicode TrueType fonts can be found at this address: http:    //www.slovo.info/unifonts.htm\n \
 \n \
 \n \
+\n \
+  Automounting\n \
+  =-=-=-=-=-=-=\n \
+\n \
+ Starting with version 2.1, Xfe has an integrated automounter program that allows to mount removable disks or media\n \
+ when they are inserted. The automounter also supports MTP devices (ex: Android phones or tablets).\n \
+\n \
+ The automounter is optional and should only be used if your system does not already provides that feature. By\n \
+ default, it is disabled and can be enabled in the Edit / Preferences / Settings dialog.\n \
+\n \
+ The automounter relies on udisks2 and gvfs / gio, so these components must be installed on your system. The process\n \
+ is called xfe-automount and is launched at first startup of Xfe. It can possibly be added to your session startup\n \
+ programs.\n \
+\n \
+\n \
+\n \
+  Network Shares\n \
+  =-=-=-=-=-=-=-=\n \
+\n \
+ Starting with version 2.1, it is possible to mount a Windows network share or to connect to an SSH server\n \
+ (Linux only, gvfs / gio must be installed). For that, use the Tools / Connect to Server menu item (Shift-F5\n \
+ shortcut) or use the Connect to Server toolbar icon. This will display a dialog asking for your connection\n \
+ parameters.\n \
+\n \
+ It is possible to safely retain connection passwords provided that the secret-tool utility is installed on your\n \
+ system. Note that in Debian based distributions this utility is provided by the libsecret-tools package. In other\n \
+ distributions, it is usually included in the libsecret library.\n \
+\n \
+\n \
+\n \
+  Custom Color Themes\n \
+  =-=-=-=-=-=-=-=-=-=\n \
+ Starting with version 2.1, it is possible to save the current theme to a custom theme, that can be renamed\n \
+ or removed. You can thus have different custom color themes and easily switch between them.\n \
+\n \
+\n \
 \n \
   Tips\n \
   =-=-=\n \
@@ -354,8 +414,9 @@
     - When dragging a file/folder to a folder, hold on the mouse on the folder to expand it\n \
 \n \
  Copy/paste file path or name\n \
-    - Select a file and press Ctrl-C to copy the file path to the clipboard. Then in a dialog or an application, press Ctrl-V \n \
-      to paste the file path. Use the Copy name menu item (or press Ctrl-Shift-N) to copy the file name (without path) to the clipboard. \n \
+    - Select a file and press Ctrl-C to copy the file path to the clipboard. Then in a dialog or an application,\n \
+      press Ctrl-V to paste the file path. Use the Copy name menu item (or press Ctrl-Shift-N) to copy the file\n \
+      name (without path) to the clipboard. \n \
     - In a file operation dialog, select a file name in the line containing the source name and paste it directly\n \
       to the destination using the middle button of your mouse. Then modify it to suit your needs.\n \
 \n \
@@ -409,11 +470,10 @@
 \n \
  If you have coded some interesting patch, please send it to me, I will try to include it in the next release...\n \
 \n \
+ Many thanks to Maxim Baranov for his excellent X Win Commander, to Jeroen van der Zijp for the FOX toolkit\n \
+ and  to all people that have provided useful patches, translations, tests and advices.\n \
 \n \
- Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful\n \
- patches, translations, tests and advices.\n \
-\n \
- [Last revision: 18/01/2025]\n \
+ [Last revision: 11/05/2025]\n \
 \n \
 ");
 
