@@ -11,6 +11,9 @@
 #include "icons.h"
 #include "MessageBox.h"
 
+// Application exec path
+extern FXString execpath;
+
 // Icons (global variables)
 
 FXIcon* bigattribicon;
@@ -65,6 +68,9 @@ FXIcon* bigsearchicon;
 FXIcon* bigreplaceicon;
 FXIcon* bigrunicon;
 FXIcon* biglinkbadgeicon;
+FXIcon* bigsavefileicon;
+FXIcon* bigsaveasicon;
+FXIcon* bigservericon;
 
 FXIcon* miniarchaddicon;
 FXIcon* miniarchexticon;
@@ -197,6 +203,11 @@ FXIcon* minidownicon;
 FXIcon* miniremovabledeviceicon;
 FXIcon* miniclosefiltericon;
 FXIcon* minilinkbadgeicon;
+FXIcon* minicloseicon;
+FXIcon* miniaddicon;
+FXIcon* mininewtabicon;
+FXIcon* miniremovetabicon;
+FXIcon* miniservericon;
 
 FXIcon* xfeicon;
 FXIcon* xfaicon;
@@ -211,28 +222,51 @@ FXIcon* hsvmodeicon;
 FXIcon* listmodeicon;
 FXIcon* rgbmodeicon;
 
+FXIcon* docktopicon;
+FXIcon* docklefticon;
+FXIcon* dockrighticon;
+FXIcon* dockbottomicon;
+FXIcon* dockflipicon;
+FXIcon* dockfreeicon;
+
 
 // Load all application icons as global variables
-FXbool loadAppIcons(FXApp* app, FXbool* iconpathfound)
+FXbool loadAppIcons(FXApp* app, FXuint* iconpathstatus)
 {
-    *iconpathfound = true;
+    *iconpathstatus = ICONPATH_FOUND;
     FXbool success = true;
 
     // Fractional scaling factor
     FXint res = app->reg().readUnsignedEntry("SETTINGS", "screenres", 100);
     double scalefrac = FXMAX(1.0, res / 100.0);
 
-    // Set icon path if it exists, otherwise set icon path to default
-    FXString iconpath = app->reg().readStringEntry("SETTINGS", "iconpath", DEFAULTICONPATH);
+    // Default icon path
+    FXString defaulticonpath = xf_realpath(FXPath::directory(execpath) + "/../share/xfe/icons/default-theme");
+
+    // Select icon path
+    FXString iconpath = xf_realpath(app->reg().readStringEntry("SETTINGS", "iconpath", defaulticonpath.text()));
     if (iconpath[0] == '~')
     {
         iconpath = FXSystem::getHomeDirectory() + iconpath.after('~');
     }
 
+    // Icon path does not exist
     if (!xf_existfile(iconpath))
     {
-        iconpath = DEFAULTICONPATH;
-        *iconpathfound = false;
+        *iconpathstatus = ICONPATH_NOT_FOUND;
+    
+        // Default icon path does not exist
+        if (!xf_existfile(defaulticonpath))
+        {
+            *iconpathstatus = DEFAULTICONPATH_NOT_FOUND;
+        }
+
+        // Set icon path to default
+        else
+        {
+            iconpath = defaulticonpath;
+            app->reg().writeStringEntry("SETTINGS", "iconpath", iconpath.text());
+        }
     }
 
     // Colors for blending
@@ -240,6 +274,9 @@ FXbool loadAppIcons(FXApp* app, FXbool* iconpathfound)
     FXColor backColor = app->getBackColor();
 
     // Load icons and set the success flag
+    FXbool firstpass = true;
+
+load:
 
     // Big icons with base color background
     success = ((bigattribicon = xf_loadiconfile(app, iconpath, "bigattrib.png", scalefrac, baseColor)) != NULL) & success;
@@ -275,6 +312,9 @@ FXbool loadAppIcons(FXApp* app, FXbool* iconpathfound)
     success = ((bigreplaceicon = xf_loadiconfile(app, iconpath, "bigreplace.png", scalefrac, baseColor)) != NULL) & success;
     success = ((bigrunicon = xf_loadiconfile(app, iconpath, "bigrun.png", scalefrac, baseColor)) != NULL) & success;
     success = ((biglinkbadgeicon = xf_loadiconfile(app, iconpath, "biglinkbadge.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((bigsavefileicon = xf_loadiconfile(app, iconpath, "bigsavefile.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((bigsaveasicon = xf_loadiconfile(app, iconpath, "bigsaveas.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((bigservericon = xf_loadiconfile(app, iconpath, "bigserver.png", scalefrac, baseColor)) != NULL) & success;
 
     // Big icons with back color background
     success = ((bigblockdevicon = xf_loadiconfile(app, iconpath, "bigblockdev.png", scalefrac, backColor)) != NULL) & success;
@@ -390,7 +430,6 @@ FXbool loadAppIcons(FXApp* app, FXbool* iconpathfound)
     success = ((minigreenbuttonicon = xf_loadiconfile(app, iconpath, "minigreenbutton.png", scalefrac, baseColor)) != NULL) & success;
     success = ((minigraybuttonicon = xf_loadiconfile(app, iconpath, "minigraybutton.png", scalefrac, baseColor)) != NULL) & success;
     success = ((minikeybindingsicon = xf_loadiconfile(app, iconpath, "minikeybindings.png", scalefrac, baseColor)) != NULL) & success;
-    success = ((minikeybindingsicon = xf_loadiconfile(app, iconpath, "minikeybindings.png", scalefrac, baseColor)) != NULL) & success;
     success = ((minirestoreicon = xf_loadiconfile(app, iconpath, "minirestore.png", scalefrac, baseColor)) != NULL) & success;
     success = ((minihorzpanelsicon = xf_loadiconfile(app, iconpath, "minihorzpanels.png", scalefrac, baseColor)) != NULL) & success;
     success = ((minivertpanelsicon = xf_loadiconfile(app, iconpath, "minivertpanels.png", scalefrac, baseColor)) != NULL) & success;
@@ -401,6 +440,11 @@ FXbool loadAppIcons(FXApp* app, FXbool* iconpathfound)
     success = ((miniremovabledeviceicon = xf_loadiconfile(app, iconpath, "miniremovabledevice.png", scalefrac, baseColor)) != NULL) & success;
     success = ((miniclosefiltericon = xf_loadiconfile(app, iconpath, "miniclosefilter.png", scalefrac, baseColor)) != NULL) & success;
     success = ((minilinkbadgeicon = xf_loadiconfile(app, iconpath, "minilinkbadge.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((minicloseicon = xf_loadiconfile(app, iconpath, "miniclose.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((miniaddicon = xf_loadiconfile(app, iconpath, "miniadd.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((mininewtabicon = xf_loadiconfile(app, iconpath, "mininewtab.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((miniremovetabicon = xf_loadiconfile(app, iconpath, "miniremovetab.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((miniservericon = xf_loadiconfile(app, iconpath, "miniserver.png", scalefrac, baseColor)) != NULL) & success;
 
     // Mini icons with back color background
     success = ((minicdromicon = xf_loadiconfile(app, iconpath, "minicdrom.png", scalefrac, backColor)) != NULL) & success;
@@ -448,5 +492,35 @@ FXbool loadAppIcons(FXApp* app, FXbool* iconpathfound)
     success = ((listmodeicon = xf_loadiconfile(app, iconpath, "listmode.png", scalefrac, baseColor)) != NULL) & success;
     success = ((rgbmodeicon = xf_loadiconfile(app, iconpath, "rgbmode.png", scalefrac, baseColor)) != NULL) & success;
 
+    success = ((docktopicon = xf_loadiconfile(app, iconpath, "docktop.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((dockbottomicon = xf_loadiconfile(app, iconpath, "dockbottom.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((docklefticon = xf_loadiconfile(app, iconpath, "dockleft.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((dockrighticon = xf_loadiconfile(app, iconpath, "dockright.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((dockflipicon = xf_loadiconfile(app, iconpath, "dockflip.png", scalefrac, baseColor)) != NULL) & success;
+    success = ((dockfreeicon = xf_loadiconfile(app, iconpath, "dockfree.png", scalefrac, baseColor)) != NULL) & success;
+
+
+    // If some icons from icon path were missing, reload using default icon path 
+    if (!success && firstpass)
+    {
+        *iconpathstatus = ICONPATH_MISSING_ICONS;
+        
+        // Default icon path does not exist
+        if (!xf_existfile(defaulticonpath))
+        {
+            *iconpathstatus = DEFAULTICONPATH_NOT_FOUND;
+        }
+
+        // Set icon path to default
+        else
+        {
+            iconpath = defaulticonpath;
+            app->reg().writeStringEntry("SETTINGS", "iconpath", iconpath.text());
+        }
+
+        firstpass = false;
+        goto load;
+    }
+    
     return success;
 }
