@@ -28,6 +28,9 @@
 // Main window
 FXMainWindow* mainWindow = NULL;
 
+// Exec path
+FXString execpath;
+
 // Integer UI scaling factor
 FXint scaleint = 1;
 
@@ -54,11 +57,7 @@ static int x_error_handler(Display* xdisplay, XErrorEvent* error)
         }
 
         fprintf(stderr, "Unexpected X error: %s serial %ld error_code %d request_code %d minor_code %d)\n",
-                buf,
-                error->serial,
-                error->error_code,
-                error->request_code,
-                error->minor_code);
+                buf, error->serial, error->error_code, error->request_code, error->minor_code);
     }
 
     return 1; // Return value is meaningless
@@ -389,6 +388,11 @@ int main(int argc, char* argv[])
     textdomain(PACKAGE);
 #endif
 
+#if defined(__FreeBSD__)
+    FXuint pkg_format;
+    pkg_format = OTHER_PKG;
+#endif
+
 #if defined(linux)
     // For package query on Linux systems, try to guess if the default package format is deb or rpm:
     //   - if dpkg exists then the system uses deb packages
@@ -440,8 +444,8 @@ int main(int argc, char* argv[])
         {
             maximized = true;
         }
-        else if ((compare(argv[i], "-p") == 0) || (compare(argv[i], "--panel") == 0) || (compare(argv[i],
-                                                                                                 "--panels") == 0))
+        else if ((compare(argv[i], "-p") == 0) || (compare(argv[i], "--panel") == 0) ||
+                 (compare(argv[i], "--panels") == 0))
         {
             if (++i < argc)
             {
@@ -519,8 +523,9 @@ int main(int argc, char* argv[])
     application->setBorderColor(bordercolor);
 
     // Load all application icons
-    FXbool iconpathfound = true;
-    loadicons = loadAppIcons(application, &iconpathfound);
+    FXuint iconpathstatus;
+    execpath = xf_execpath(argv[0]);
+    loadicons = loadAppIcons(application, &iconpathstatus);
 
     // Set normal font
     FXString fontspec;
@@ -552,18 +557,28 @@ int main(int argc, char* argv[])
     application->setTooltipPause(TOOLTIP_PAUSE);
     application->setTooltipTime(TOOLTIP_TIME);
 
-    // Icon path not found
-    if (!iconpathfound)
+    // Icon path doesn't exist
+    if (iconpathstatus == ICONPATH_NOT_FOUND)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Icon path doesn't exist, icon theme was set back to default. Please check your icon path!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Icon path doesn't exist, default icon path was selected.\
+\n\nFrom Xfe, please check your icon path in Edit / Preferences / Appearance..."));
     }
 
     // Some icons not found
-    if (!loadicons)
+    if (!loadicons && iconpathstatus == ICONPATH_MISSING_ICONS)
     {
-        MessageBox::error(application, BOX_OK, _("Error loading icons"),
-                          _("Unable to load some icons. Please check your icon theme!"));
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load some icons, default icon theme was selected.\
+\n\nFrom Xfe, please check your icon theme in Edit / Preferences / Appearance..."));       
+    }
+
+    // Default icon path doesn't exist
+    if (iconpathstatus == DEFAULTICONPATH_NOT_FOUND)
+    {
+        MessageBox::error(application->getRootWindow(), BOX_OK, _("Error loading icons"),
+                          _("Unable to load default icons, no icons can be shown.\
+\n\nPlease check your Xfe installation..."));       
     }
 
     return application->run();
