@@ -70,13 +70,13 @@ enum
 #endif
 
 // Maximum number of files that can be opened in a file dialog
-#ifndef NMAX_OPEN_FILES
-#define NMAX_OPEN_FILES   1000
+#ifndef MAX_OPEN_FILES
+#define MAX_OPEN_FILES   1000
 #endif
 
 // Maximum length of a file path
 #ifndef MAXPATHLEN
-#define MAXPATHLEN    8192
+#define MAXPATHLEN    4096
 #endif
 
 // Maximum length of a command line
@@ -94,19 +94,39 @@ enum
 #define MAX_FIND_SIZE    256
 #endif
 
+// Maximum length of a server name
+#ifndef MAX_SERVER_SIZE
+#define MAX_SERVER_SIZE    256
+#endif
+
+// Maximum length of a share name
+#ifndef MAX_SHARE_SIZE
+#define MAX_SHARE_SIZE    256
+#endif
+
+// Maximum length of a domain name
+#ifndef MAX_DOMAIN_SIZE
+#define MAX_DOMAIN_SIZE    256
+#endif
+
+// Maximum length of a user name
+#ifndef MAX_USER_SIZE
+#define MAX_USER_SIZE    256
+#endif
+
 // Maximum number of characters per line for one line messages
 #ifndef MAX_MESSAGE_LENGTH
 #define MAX_MESSAGE_LENGTH    96
 #endif
 
-// Minimum file name size in detailed view
+// Minimum file name size (in pixels) in detailed view
 #ifndef MIN_NAME_SIZE
 #define MIN_NAME_SIZE    250
 #endif
 
-// Maximum file name size in detailed view
+// Maximum file name size (in pixels) in detailed view
 #ifndef MAX_NAME_SIZE
-#define MAX_NAME_SIZE    2000
+#define MAX_NAME_SIZE    1000
 #endif
 
 // Root directory string
@@ -131,6 +151,11 @@ enum
 #define NMAX_COLS  9
 #endif
 
+// Maximum number of tabs
+#ifndef NMAX_TABS
+#define NMAX_TABS    100
+#endif
+
 // Maximum number of path links
 #ifndef NMAX_LINKS
 #define NMAX_LINKS    100
@@ -151,18 +176,41 @@ enum
 #define FILTER_HIST_SIZE    100
 #endif
 
-
 // Find history size
 #ifndef FIND_HIST_SIZE
 #define FIND_HIST_SIZE    100
 #endif
 
+// Server history size
+#ifndef SERVER_HIST_SIZE
+#define SERVER_HIST_SIZE    100
+#endif
+
+// Share history size
+#ifndef SHARE_HIST_SIZE
+#define SHARE_HIST_SIZE    100
+#endif
+
+// Domain history size
+#ifndef DOMAIN_HIST_SIZE
+#define DOMAIN_HIST_SIZE    100
+#endif
+
+// User history size
+#ifndef USER_HIST_SIZE
+#define USER_HIST_SIZE    100
+#endif
 
 // Buffer length for file copy
 #ifndef BUFFER_COPY_SIZE
 #define BUFFER_COPY_SIZE    1048576
 #endif
 
+// Time interval to check for MTP devices (ms)
+#define MTP_CHECK_INTERVAL    1000
+
+// Maximum length of an MTP name string
+#define MAX_MTP_NAME_SIZE     1024
 
 // If startup notification is used, this is the timeout value (seconds)
 #ifdef STARTUP_NOTIFICATION
@@ -235,12 +283,6 @@ enum
 #define XFECONFIGNAME    "xferc"
 #endif
 
-// Default icon path
-#ifndef DEFAULTICONPATH
-#define DEFAULTICONPATH \
-        "~/.config/xfe/icons/default-theme:/usr/local/share/xfe/icons/default-theme:/usr/share/xfe/icons/default-theme"
-#endif
-
 // Command to launch Xfe as root with pkexec
 #ifndef DEFAULT_PKEXEC_CMD
 #define DEFAULT_PKEXEC_CMD    "pkexec xfe"
@@ -351,6 +393,9 @@ enum
 // Macro to add parentheses before and after a given string
 #define PARS(s)    ((FXString)" (" + (s) + (FXString)")")
 
+#if defined(__FreeBSD__)
+#define OTHER_PKG    2
+#endif
 
 // Linux specials
 
