@@ -787,6 +787,7 @@ size_t xf_strlcpy(char* dst, const char* src, size_t sz)
     return 0;
 }
 
+
 // Safe strcat function (Public domain, by C.B. Falconer)
 // The destination string is always null terminated
 size_t xf_strlcat(char* dst, const char* src, size_t sz)
@@ -1097,6 +1098,92 @@ FXString xf_filepath(const FXString path, const FXString dir)
 }
 
 
+// Obtain real pathname (remove ../ and ./ from absolute path)
+FXString xf_realpath(const FXString path)
+{
+    char buf[MAXPATHLEN];
+    FXString ret;
+    
+    // Get real pathname
+    char* res = realpath(path.text(), buf);
+    if (res != NULL)
+    {
+        ret = FXString(res);
+    }
+   
+    // An error has occurred, return original pathname
+    else
+    {
+        ret = path;
+    }
+    
+    return ret;
+}
+
+
+// Return the absolute path of the application executable
+// Exit application if error
+// Source: https://www.linuxquestions.org/questions/programming-9/c-function-to-get-application-path-335442/
+FXString xf_execpath(char* path)
+{
+    FXString execpath;
+    char abs_exe_path[MAXPATHLEN] = "";
+    int ret;
+
+#if defined(linux)
+    ret = readlink("/proc/self/exe", abs_exe_path, MAXPATHLEN);
+    if (ret < 0)
+    {
+        goto err;
+    }
+    
+#else
+    char path_save[MAXPATHLEN];
+    char *p1, *p2;
+
+    if(!(p1 = strrchr(path, '/')))
+    {
+        p2 = getcwd(abs_exe_path, sizeof(abs_exe_path));
+    }
+    else
+    {
+        *p1 = '\0';
+        p2 = getcwd(path_save, sizeof(path_save));
+        if (p2 == NULL)
+        {
+            goto err;
+        }
+
+        ret = chdir(path);
+        if (ret < 0)
+        {
+            goto err;
+        }
+
+        p2 = getcwd(abs_exe_path, sizeof(abs_exe_path));
+        if (p2 == NULL)
+        {
+            goto err;
+        }
+    
+        ret = chdir(path_save);
+        if (ret < 0)
+        {
+            goto err;
+        }
+    }
+    
+#endif
+
+    execpath = abs_exe_path;
+    return execpath;
+
+err:
+        fprintf(stderr, _("Error: %s\n"), strerror(errno));
+        exit(EXIT_FAILURE);
+}
+
+
 // Obtain file path from URI specified as file:///bla/bla/bla...
 // If no 'file:' prefix is found, return the input string as is
 FXString xf_filefromuri(FXString uri)
@@ -1798,7 +1885,7 @@ FXString xf_getcommandoutput(FXString cmd)
 
 // Load a PNG icon from a file in the icon path
 FXIcon* xf_loadiconfile(FXApp* app, const FXString iconpath, const FXString iconname,
-                        const double scalefrac, const FXColor blendColor)
+                        const double scalefrac, const FXColor blendcolor)
 {
     // Icon name is empty
     if (iconname.length() == 0)
@@ -1832,7 +1919,7 @@ FXIcon* xf_loadiconfile(FXApp* app, const FXString iconpath, const FXString icon
                 icon->scale(scalefrac * icon->getWidth(), scalefrac * icon->getHeight());
 
                 // Blend it
-                icon->blend(blendColor);
+                icon->blend(blendcolor);
 
                 // Create it
                 icon->create();
@@ -1866,6 +1953,7 @@ FXString xf_truncline(FXString str, FXuint maxlinesize)
 
 // Insert line breaks as needed to allow displaying string using lines
 // of specified maximum number of UTF-8 characters
+// Don't insert line breaks in a middle of a word
 FXString xf_multilines(FXString str, FXuint maxlinesize)
 {
     int pos1 = 0;
@@ -1883,7 +1971,20 @@ FXString xf_multilines(FXString str, FXuint maxlinesize)
                 int nbl = nbc / maxlinesize;
                 for (int n = 1; n <= nbl; n++)
                 {
-                    str.insert(str.validate(pos1 + n * maxlinesize), '\n'); // Use a valid UTF-8 position
+                    // Don't insert line break in a middle of a word
+                    int pos3 = str.find(' ', pos1 + n * maxlinesize);
+                    if (pos3 < 0)
+                    {
+                        str.insert(str.validate(pos1 + n * maxlinesize), '\n'); // Use a valid UTF-8 position
+                    }
+                    else
+                    {
+                        // Don't insert line break before '?' or '!' 
+                        if ( (str.find('?', pos3 + 1) < 0) && (str.find('!', pos3 + 1) < 0) )
+                        {
+                            str.insert(str.validate(pos3 + 1), '\n'); // Use a valid UTF-8 position
+                        } 
+                    }
                 }
             }
 
@@ -1898,7 +1999,21 @@ FXString xf_multilines(FXString str, FXuint maxlinesize)
                 int nbl = nbc / maxlinesize;
                 for (int n = 1; n <= nbl; n++)
                 {
-                    str.insert(str.validate(pos1 + n * maxlinesize), '\n'); // Use a valid UTF-8 position
+                    // Don't insert line break in a middle of a word
+                    int pos3 = str.find(' ', pos1 + n * maxlinesize);
+                    if (pos3 < 0)
+                    {
+                        str.insert(str.validate(pos1 + n * maxlinesize), '\n'); // Use a valid UTF-8 position
+                    }
+                    else
+                    {
+                        // Don't insert line break before '?' or '!' 
+                        if ( (str.find('?', pos3 + 1) < 0) && (str.find('!', pos3 + 1) < 0) )
+                        {
+                            str.insert(str.validate(pos3 + 1), '\n'); // Use a valid UTF-8 position
+                        } 
+                    }
+  
                     pos2++;
                 }
             }
@@ -1909,6 +2024,7 @@ FXString xf_multilines(FXString str, FXuint maxlinesize)
     return str;
 }
 
+
 // Helper function to filter out some file systems from the mounts check
 FXbool xf_keepmount(FXString mntdir, FXString mntname)
 {
@@ -2050,7 +2166,7 @@ FXString xf_substitutecase(const FXString& str, const FXString& org, const FXStr
 // Return 0 if file can't be read
 FXulong xf_hashfile(const FXchar* filename)
 {
-    FXulong hash = 7873;
+    FXlong hash = 7873;
     int c;
     FILE* file = fopen(filename, "r");
 
@@ -2067,5 +2183,5 @@ FXulong xf_hashfile(const FXchar* filename)
 
     fclose(file);
 
-    return hash;
+    return (FXulong)FXMAX(hash, 0);
 }
