@@ -53,7 +53,7 @@ extern FXStringDict* updevices;
 
 
 // Vector of strings
-typedef std::vector<FXString> vector_FXString;
+typedef std::vector<FXString>   vector_FXString;
 
 
 // Single click types
@@ -98,6 +98,15 @@ enum
 };
 
 
+// New tab directory modes
+enum
+{
+    NEWTAB_HOMEDIR        = 0,
+    NEWTAB_CURRENTDIR     = 1,
+    NEWTAB_ROOTDIR        = 2,
+};
+
+
 // Note : some inline functions must be declared in the header file or they won't compile!
 
 
@@ -533,7 +542,11 @@ static inline int xf_statvfs_timeout(const char* filename, FXuint timeout)
                 if (difftime(t, t0) > timeout)
                 {
                     kill(pid, SIGKILL);
-                    waitpid(pid, NULL, WNOHANG);                // Avoids zombies
+                    int ret = waitpid(pid, NULL, WNOHANG);      // Avoids zombies
+                    if (ret < 0)                                // Should not happen
+                    {
+                        fprintf(stderr, "%s", strerror(errno));
+                    }
                     return 1;                                   // Return 1 on timeout
                 }
             }
@@ -647,6 +660,8 @@ FXString xf_humansize(char*);
 FXString xf_cleanpath(const FXString);
 FXString xf_filepath(const FXString);
 FXString xf_filepath(const FXString, const FXString);
+FXString xf_realpath(const FXString);
+FXString xf_execpath(char*);
 
 FXString xf_filefromuri(FXString);
 FXString xf_filetouri(const FXString&);
